@@ -42,6 +42,26 @@
 #define CODECHAL_ENCODE_HEVC_MAX_NUM_ROI    16
 #define CODECHAL_HEVC_FRAME_HEADER_SIZE     8192
 #define CODECHAL_HEVC_MAX_LCU_SIZE_G10      64
+#define CODECHAL_ENCODE_RECYCLED_BUFFER_NUM 6
+
+#define CODECHAL_HEVC_BRC_MAX_QUALITY_LAYER   16
+#define CODECHAL_HEVC_BRC_MAX_TEMPORAL_LAYER  3
+#define CODECHAL_HEVC_MAX_BSTRUCTRUE_GOP_SIZE 16
+#define CODECHAL_HEVC_MAX_BSTRUCTRUE_REF_NUM  8
+#define CODECHAL_HEVC_NUM_MODE_MV_COSTS       171
+
+#define CODECHAL_HEVC_VDENC_MIN_TILE_WIDTH_SIZE  256
+#define CODECHAL_HEVC_VDENC_MIN_TILE_HEIGHT_SIZE 128
+#define CODECHAL_HEVC_SAO_STRMOUT_SIZE_PERLCU    16
+#define CODECHAL_HEVC_VDENC_STATS_SIZE           1216
+#define HEVC_BRC_PAK_STATISTCS_SIZE              32
+
+#define CODECHAL_VDENC_HEVC_BRC_HUC_STATUS_REENCODE_MASK     (1<<31)
+
+#define CODECHAL_HEVC_I_SLICE          2
+#define CODECHAL_HEVC_P_SLICE          1
+#define CODECHAL_HEVC_B_SLICE          0
+#define CODECHAL_HEVC_NUM_SLICE_TYPES  3
 
 // HEVC VDENC
 #define ENCODE_HEVC_VDENC_NUM_MAX_SLICES        70
@@ -62,6 +82,20 @@
 #define ENCODE_DP_HEVC_ROI_BLOCK_Width        16
 #define ENCODE_DP_HEVC_ROI_BLOCK_HEIGHT       16
 
+//!
+//! \enum     HEVC_BRC_FRAME_TYPE
+//! \brief    HEVC BRC frame type
+//!
+enum HEVC_BRC_FRAME_TYPE
+{
+    HEVC_BRC_FRAME_TYPE_P_OR_LB = 0,
+    HEVC_BRC_FRAME_TYPE_B = 1,
+    HEVC_BRC_FRAME_TYPE_I = 2,
+    HEVC_BRC_FRAME_TYPE_B1 = 3,
+    HEVC_BRC_FRAME_TYPE_B2 = 4,
+    HEVC_BRC_FRAME_TYPE_INVALID
+};
+
 typedef enum
 {
     ENCODE_HEVC_BIT_DEPTH_8     = 0,
