@@ -163,7 +163,7 @@ typedef enum _CM_RETURN_CODE
     CM_INVALID_CREATE_OPTION_FOR_BUFFER_STATELESS = -103,
     CM_INVALID_KERNEL_ARG_POINTER                 = -104,
     CM_SYSTEM_MEMORY_NOT_2PIXELS_ALIGNED          = -105,
-
+    CM_NO_SUPPORTED_ADAPTER                       = -106,
     /*
      * RANGE -10000 ~ -19999 FOR INTERNAL ERROR CODE
      */
@@ -533,7 +533,8 @@ typedef struct _CM_TASK_CONFIG
 {
     bool     turboBoostFlag      : 1;
     bool     fusedEuDispatchFlag : 1;
-    uint32_t reserved_bits       :30;
+    bool     enableFenceFlag     : 1;
+    uint32_t reserved_bits       :29;
     uint32_t reserved0;
     uint32_t reserved1;
     uint32_t reserved2;
