@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -68,18 +68,20 @@ static uint32_t HalCm_CopyHexDwordLine(char  *destBuf, size_t buflen, uint32_t *
 //!           flag to control if need time stamp
 //! \param    [in] counter
 //!           dump file counter
-//! \param    [in] pValueName
-//!           pointer to value name, used for user feature read
 //! \param    [in] outputDir
 //!           pointer to output dir
 //! \param    [in] outputFile
 //!           pointer output file prefix
 //! \return   number of bytes written
 //!
-int32_t GetFileNameAndCounter(char fileNamePrefix[], bool timeStampFlag, int32_t counter,
-                              const char *pValueName, const char *outputDir,const char *outputFile)
+int32_t GetFileNameAndCounter(char fileNamePrefix[],
+                              bool timeStampFlag,
+                              int32_t counter,
+                              const char *outputDir,
+                              const char *outputFile,
+                              CM_HAL_STATE *halState)
 {
-    GetLogFileLocation(outputDir, fileNamePrefix);
+    GetLogFileLocation(outputDir, fileNamePrefix, halState->osInterface->pOsContext);
     PlatformSNPrintf(fileNamePrefix + strlen(fileNamePrefix), 
                      MOS_MAX_HLT_FILENAME_LEN - strlen(fileNamePrefix), PLATFORM_DIR_SEPERATOR);
 
@@ -97,17 +99,23 @@ int32_t GetFileNameAndCounter(char fileNamePrefix[], bool timeStampFlag, int32_t
         //check if command buffer or surface state counter, and get it
         if (!strcmp(outputFile,"Command_Buffer"))
         {
-            counter = GetCommandBufferDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER);
+            counter = GetCommandBufferDumpCounter(
+                __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER_ID,
+                halState->osInterface->pOsContext);
         }
         else if (!strcmp(outputFile,"Surface_State_Dump"))
         {
-            counter = GetSurfaceStateDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER);
+            counter = GetSurfaceStateDumpCounter(
+                __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER_ID,
+                halState->osInterface->pOsContext);
         }
         else if (!strcmp(outputFile, "Interface_Descriptor_Data_Dump"))
         {
-            counter = GetInterfaceDescriptorDataDumpCounter(__MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_COUNTER);
+            counter = GetInterfaceDescriptorDataDumpCounter(
+                __MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_COUNTER_ID,
+                halState->osInterface->pOsContext);
         }
-       
+
         PlatformSNPrintf(fileNamePrefix + strlen(fileNamePrefix), 
                          MOS_MAX_HLT_FILENAME_LEN - strlen(fileNamePrefix), "%s_%d.txt", outputFile, counter);
     }
@@ -130,48 +138,40 @@ int32_t GetFileNameAndCounter(char fileNamePrefix[], bool timeStampFlag, int32_t
 //!
 int32_t HalCm_InitDumpCommandBuffer(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    char                            fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                      eStatus;
+    MOS_USER_FEATURE_VALUE_DATA     userFeatureValueData;
+    int32_t                         hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if command buffer dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
+    GetLogFileLocation(HALCM_COMMAND_BUFFER_OUTPUT_DIR, fileName,
+                       state->osInterface->pOsContext);
 
-    GetLogFileLocation(HALCM_COMMAND_BUFFER_OUTPUT_DIR, fileName);
-
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_ENABLE,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_ENABLE_ID,
+        &userFeatureValueData,
+        state->osInterface->pOsContext);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read command buffer user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
-       
-        eStatus = MOS_CreateDirectory(fileName);
+        eStatus = MosUtilities::MosCreateDirectory(fileName);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to create output directory. Status = %d", eStatus);
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpCommandBuffer = userFeatureValue.bData?true: false;
-        if (userFeatureValue.bData == 17)
+        state->dumpCommandBuffer = userFeatureValueData.bData ? true : false;
+        if (userFeatureValueData.bData == 17)
         {
             state->enableCMDDumpTimeStamp = true;
         }
@@ -220,10 +220,9 @@ int32_t HalCm_DumpCommadBuffer(PCM_HAL_STATE state, PMOS_COMMAND_BUFFER cmdBuffe
 
    //Check if use timestamp in cmd buffer dump file
     commandBufferNumber = GetFileNameAndCounter(fileName, state->enableCMDDumpTimeStamp,
-                          commandBufferNumber,
-                          __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER, 
-                          HALCM_COMMAND_BUFFER_OUTPUT_DIR,
-                          HALCM_COMMAND_BUFFER_OUTPUT_FILE);
+                                                commandBufferNumber,
+                                                HALCM_COMMAND_BUFFER_OUTPUT_DIR,
+                                                HALCM_COMMAND_BUFFER_OUTPUT_FILE, state);
 
     //get the command buffer header size
     offset = GetCommandBufferHeaderDWords(osInterface);
@@ -243,14 +242,15 @@ int32_t HalCm_DumpCommadBuffer(PCM_HAL_STATE state, PMOS_COMMAND_BUFFER cmdBuffe
     // write command buffer dwords.
     bytesWritten += HalCm_CopyHexDwordLine(outputBuffer, sizeToAllocate - bytesWritten,
                                           (uint32_t *)cmdBuffer->pCmdBase + offset, numberOfDwords);
-    MOS_OS_CHK_STATUS(MOS_WriteFileFromPtr((const char *)fileName, outputBuffer, bytesWritten));
+    MOS_OS_CHK_STATUS(MosUtilities::MosWriteFileFromPtr((const char *)fileName, outputBuffer, bytesWritten));
     commandBufferNumber++;
 
     //Record command buffer dump counter
     if (!state->enableCMDDumpTimeStamp)
     {        
         RecordCommandBufferDumpCounter(commandBufferNumber,
-                                       __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER_ID);
+                                       __MEDIA_USER_FEATURE_VALUE_MDF_CMD_DUMP_COUNTER_ID,
+                                       state->osInterface->pOsContext);
     }  
     hr = CM_SUCCESS;
 finish:
@@ -277,45 +277,38 @@ finish:
 //!
 int32_t HalCm_InitDumpCurbeData(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    char                        fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if curbe data dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
-
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_CURBE_DUMP_ENABLE,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_CURBE_DUMP_ENABLE_ID,
+        &userFeatureValueData,
+        state->osInterface->pOsContext);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read curbe data dump user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
-        GetLogFileLocation(HALCM_CURBE_DATA_OUTPUT_DIR, fileName);
-        eStatus = MOS_CreateDirectory(fileName);
+        GetLogFileLocation(HALCM_CURBE_DATA_OUTPUT_DIR, fileName,
+                           state->osInterface->pOsContext);
+        eStatus = MosUtilities::MosCreateDirectory(fileName);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to create curbe data output directory. Status = %d", eStatus);
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpCurbeData = userFeatureValue.bData ? true: false;
+        state->dumpCurbeData = userFeatureValueData.bData ? true : false;
     }
     hr = CM_SUCCESS;
 finish:
@@ -346,7 +339,8 @@ int32_t HalCm_DumpCurbeData(PCM_HAL_STATE state)
     MOS_OS_ASSERT(state);
 
     // Set the file name.
-    GetLogFileLocation(HALCM_CURBE_DATA_OUTPUT_DIR, fileName);
+    GetLogFileLocation(HALCM_CURBE_DATA_OUTPUT_DIR, fileName,
+                       state->osInterface->pOsContext);
 
     PlatformSNPrintf(fileName + strlen(fileName), MOS_MAX_HLT_FILENAME_LEN - strlen(fileName),
                      PLATFORM_DIR_SEPERATOR);
@@ -380,7 +374,7 @@ int32_t HalCm_DumpCurbeData(PCM_HAL_STATE state)
                           numberOfDwords);
     }
 
-    MOS_OS_CHK_STATUS(MOS_WriteFileFromPtr((const char *)fileName, outputBuffer, bytesWritten));
+    MOS_OS_CHK_STATUS(MosUtilities::MosWriteFileFromPtr((const char *)fileName, outputBuffer, bytesWritten));
 
     curbeDataNumber++;
 
@@ -414,37 +408,29 @@ finish:
 //!
 int32_t HalCm_InitSurfaceDump(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if surface content dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
-
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_DUMP_ENABLE,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_DUMP_ENABLE_ID,
+        &userFeatureValueData,
+        state->osInterface->pOsContext);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read surface content dump user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
         // Setup member function and variable.
-        state->dumpSurfaceContent = userFeatureValue.bData ? true: false;
+        state->dumpSurfaceContent = userFeatureValueData.bData ? true : false;
     }
     hr = CM_SUCCESS;
 finish:
@@ -460,48 +446,41 @@ finish:
 
 int32_t HalCm_InitDumpSurfaceState(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    char                        fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if command buffer dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
+    GetLogFileLocation(HALCM_SURFACE_STATE_OUTPUT_DIR, fileName,
+                       state->osInterface->pOsContext);
 
-    GetLogFileLocation(HALCM_SURFACE_STATE_OUTPUT_DIR, fileName);
-
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_ENABLE,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_ENABLE_ID,
+        &userFeatureValueData,
+        state->osInterface->pOsContext);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read surface state user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
-        eStatus = MOS_CreateDirectory(fileName);
+        eStatus = MosUtilities::MosCreateDirectory(fileName);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to create output directory. Status = %d", eStatus);
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpSurfaceState = userFeatureValue.bData ? true : false;
+        state->dumpSurfaceState = userFeatureValueData.bData ? true : false;
 
-        if (userFeatureValue.bData == 17)
+        if (userFeatureValueData.bData == 17)
         {
             state->enableSurfaceStateDumpTimeStamp = true;
         }
@@ -541,11 +520,12 @@ int32_t HalCm_DumpSurfaceState(PCM_HAL_STATE state,  int offsetSurfaceState, siz
     uint32_t        surfacesizeToAllocate = 0;
    
    //Check if use timestamp in cmd buffer dump file
-    surfacestatedumpNumber = GetFileNameAndCounter(filename, state->enableSurfaceStateDumpTimeStamp,
-        surfacestatedumpNumber,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER,
-        HALCM_SURFACE_STATE_OUTPUT_DIR,
-        HALCM_SURFACE_STATE_OUTPUT_FILE);
+    surfacestatedumpNumber = GetFileNameAndCounter(filename,
+                                                   state->enableSurfaceStateDumpTimeStamp,
+                                                   surfacestatedumpNumber,
+                                                   HALCM_SURFACE_STATE_OUTPUT_DIR,
+                                                   HALCM_SURFACE_STATE_OUTPUT_FILE,
+                                                   state);
     
     //calculate surface state dump allocation size
     surfacesizeToAllocate = stateHeap->iCurrentSurfaceState *
@@ -570,15 +550,17 @@ int32_t HalCm_DumpSurfaceState(PCM_HAL_STATE state,  int offsetSurfaceState, siz
     }
 
     //Write to file
-    MOS_OS_CHK_STATUS(MOS_WriteFileFromPtr((const char *)filename, surfaceoutputBuffer, 
+    MOS_OS_CHK_STATUS(MosUtilities::MosWriteFileFromPtr((const char *)filename, surfaceoutputBuffer, 
                       surfacebytesWritten));
 
     surfacestatedumpNumber++;
 
     if (!state->enableSurfaceStateDumpTimeStamp)
     {
-        RecordSurfaceStateDumpCounter(surfacestatedumpNumber, 
-                                      __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER_ID);
+        RecordSurfaceStateDumpCounter(
+            surfacestatedumpNumber, 
+            __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER_ID,
+            state->osInterface->pOsContext);
     }
 
     hr = CM_SUCCESS;
@@ -601,47 +583,40 @@ finish:
 
 int32_t HalCm_InitDumpInterfaceDescriporData(PCM_HAL_STATE state)
 {
-    MOS_USER_FEATURE        userFeature;
-    char                    fileName[MOS_MAX_HLT_FILENAME_LEN];
-    MOS_STATUS              eStatus;
-    MOS_USER_FEATURE_VALUE  userFeatureValue;
-    int32_t                 hr = CM_FAILURE;
+    MOS_USER_FEATURE_VALUE_DATA userFeatureValueData;
+    char                        fileName[MOS_MAX_HLT_FILENAME_LEN];
+    MOS_STATUS                  eStatus;
+    int32_t                     hr = CM_FAILURE;
 
     MOS_OS_ASSERT(state);
 
-    MOS_ZeroMemory(&userFeatureValue, sizeof(MOS_USER_FEATURE_VALUE));
-    MOS_ZeroMemory(&userFeature, sizeof(userFeature));
+    MOS_ZeroMemory(&userFeatureValueData, sizeof(userFeatureValueData));
 
     // Check if command buffer dump was enabled in user feature settings.
-    userFeature.Type = MOS_USER_FEATURE_TYPE_USER;
-    userFeature.pPath = __MEDIA_USER_FEATURE_SUBKEY_INTERNAL;
-    userFeature.pValues = &userFeatureValue;
-    userFeature.uiNumValues = 1;
-    userFeatureValue.bData = false;
+    GetLogFileLocation(HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR, fileName,
+                       state->osInterface->pOsContext);
 
-    GetLogFileLocation(HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR, fileName);
-
-    eStatus = MOS_UserFeature_ReadValue(
+    eStatus = MOS_UserFeature_ReadValue_ID(
         nullptr,
-        &userFeature,
-        __MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_DUMP,
-        MOS_USER_FEATURE_VALUE_TYPE_INT32);
+        __MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_DUMP_ID,
+        &userFeatureValueData,
+        state->osInterface->pOsContext);
     if (eStatus != MOS_STATUS_SUCCESS)
     {
         MOS_OS_NORMALMESSAGE("Unable to read interface descriptor data dump user feature key. Status = %d", eStatus);
         goto finish;
     }
-    if (userFeatureValue.bData)
+    if (userFeatureValueData.bData)
     {
-        eStatus = MOS_CreateDirectory(fileName);
+        eStatus = MosUtilities::MosCreateDirectory(fileName);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to create output directory. Status = %d", eStatus);
             goto finish;
         }
         // Setup member function and variable.
-        state->dumpIDData = userFeatureValue.bData ? true : false;
-        if (userFeatureValue.bData == 17)
+        state->dumpIDData = userFeatureValueData.bData ? true : false;
+        if (userFeatureValueData.bData == 17)
         {
             state->enableIDDumpTimeStamp = true;
         }
@@ -680,14 +655,14 @@ int32_t HalCm_DumpInterfaceDescriptorData(PCM_HAL_STATE state)
     MOS_OS_ASSERT(state);
 
     // Set the file name.
-    GetLogFileLocation(HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR, fileName);
+    GetLogFileLocation(HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR, fileName,
+                       state->osInterface->pOsContext);
 
     //Check if use timestamp in cmd buffer dump file
     IDDNumber = GetFileNameAndCounter(fileName, state->enableIDDumpTimeStamp,
-        IDDNumber,
-        __MEDIA_USER_FEATURE_VALUE_MDF_SURFACE_STATE_DUMP_COUNTER,
-        HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR,
-        HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_FILE);
+                                      IDDNumber, HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_DIR,
+                                      HALCM_INTERFACE_DESCRIPTOR_DATA_OUTPUT_FILE,
+                                      state);
 
     // write interface descriptor data dwords.
     if (state->dshEnabled)
@@ -716,13 +691,15 @@ int32_t HalCm_DumpInterfaceDescriptorData(PCM_HAL_STATE state)
             numberOfDwords);
     }
 
-    MOS_OS_CHK_STATUS(MOS_WriteFileFromPtr((const char *)fileName, outputBuffer, bytesWritten));
+    MOS_OS_CHK_STATUS(MosUtilities::MosWriteFileFromPtr((const char *)fileName, outputBuffer, bytesWritten));
 
     IDDNumber++;
     if (!state->enableIDDumpTimeStamp)
     {
-        RecordInterfaceDescriptorDataDumpCounter(IDDNumber,
-            __MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_COUNTER_ID);
+        RecordInterfaceDescriptorDataDumpCounter(
+            IDDNumber,
+            __MEDIA_USER_FEATURE_VALUE_MDF_INTERFACE_DESCRIPTOR_DATA_COUNTER_ID,
+            state->osInterface->pOsContext);
     }
 
     hr = CM_SUCCESS;
@@ -742,4 +719,4 @@ finish:
     return hr;
 
 }
-#endif
\ No newline at end of file
+#endif
