@@ -48,6 +48,7 @@ int32_t CmTaskRT::Create(CmDeviceRT *device,
     kernelArray = new (std::nothrow) CmTaskRT( device, index, maxKernelCount );
     if( kernelArray )
     {
+        device->m_memObjectCount.taskCount++;
         result = kernelArray->Initialize();
         if( result != CM_SUCCESS )
         {
@@ -70,6 +71,7 @@ int32_t CmTaskRT::Destroy( CmTaskRT* &kernelArray )
 {
     if( kernelArray )
     {
+        kernelArray->m_device->m_memObjectCount.taskCount--;
         delete kernelArray;
         kernelArray = nullptr;
     }
@@ -173,7 +175,7 @@ int32_t CmTaskRT::AddKernelInternal( CmKernel *kernel, const CM_EXECUTION_CONFIG
 //*-----------------------------------------------------------------------------
 CM_RT_API int32_t CmTaskRT::AddKernel( CmKernel *kernel )
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
     return AddKernelInternal(kernel, nullptr);
 }
 
@@ -184,7 +186,7 @@ CM_RT_API int32_t CmTaskRT::AddKernel( CmKernel *kernel )
 CM_RT_API int32_t CmTaskRT::AddKernelWithConfig( CmKernel *kernel,
     const CM_EXECUTION_CONFIG *config )
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
     return AddKernelInternal(kernel, config);
 }
 
@@ -192,9 +194,9 @@ CM_RT_API int32_t CmTaskRT::AddKernelWithConfig( CmKernel *kernel,
 //| Purpose:    Reset task and clear all the kernel
 //| Returns:    Result of the operation.
 //*-----------------------------------------------------------------------------
-CM_RT_API int32_t CmTaskRT::Reset( void )
+CM_RT_API int32_t CmTaskRT::Reset()
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
 
     m_kernelCount = 0;
     m_syncBitmap = 0;
@@ -202,6 +204,13 @@ CM_RT_API int32_t CmTaskRT::Reset( void )
     CmSafeMemSet(&m_conditionalEndInfo, 0, sizeof(m_conditionalEndInfo));
     CmSafeMemSet(&m_taskConfig, 0, sizeof(m_taskConfig));
     m_taskConfig.turboBoostFlag = CM_TURBO_BOOST_DEFAULT;
+    CM_CHK_NULL_RETURN_CMERROR(m_device);
+    CM_CHK_NULL_RETURN_CMERROR(m_device->GetAccelData());
+    PCM_HAL_STATE cmHalState = ((PCM_CONTEXT_DATA)m_device->GetAccelData())->cmHalState;
+    CM_CHK_NULL_RETURN_CMERROR(cmHalState);
+    CM_CHK_NULL_RETURN_CMERROR(cmHalState->cmHalInterface);
+    cmHalState->cmHalInterface->InitTaskProperty(m_taskConfig);
+
     if(m_kernelArray)
     {
         CmSafeMemSet( m_kernelArray, 0, sizeof(CmKernelRT*) * m_maxKernelCount );
@@ -364,9 +373,9 @@ finish:
 //| Purpose:    Insert synchronization point before next kernel
 //| Returns:    Result of the operation.
 //*-----------------------------------------------------------------------------
-CM_RT_API int32_t CmTaskRT::AddSync( void )
+CM_RT_API int32_t CmTaskRT::AddSync()
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
 
     if (m_kernelCount > 0)
     {
@@ -463,7 +472,10 @@ std::string CmTaskRT::Log()
     }
     return oss.str();
 }
-#endif
+
+CM_HAL_STATE* CmTaskRT::GetHalState() { return m_device->GetHalState(); }
+
+#endif  // #if CM_LOG_ON
 
 CM_RT_API int32_t CmTaskRT::SetProperty(const CM_TASK_CONFIG &taskConfig)
 {
@@ -477,12 +489,12 @@ CM_RT_API int32_t CmTaskRT::GetProperty(CM_TASK_CONFIG &taskConfig)
     return CM_SUCCESS;
 }
 
-CM_RT_API int32_t CmTaskRT::AddConditionalEnd(
-                                SurfaceIndex* conditionalSurfaceIndex,
-                                uint32_t offset,
-                                CM_CONDITIONAL_END_PARAM *conditionalParam)
+CM_RT_API int32_t
+CmTaskRT::AddConditionalEnd(SurfaceIndex* conditionalSurfaceIndex,
+                            uint32_t offset,
+                            CM_CONDITIONAL_END_PARAM *conditionalParam)
 {
-    INSERT_API_CALL_LOG();
+    INSERT_API_CALL_LOG(GetHalState());
 
     int32_t hr = CM_SUCCESS;
 
@@ -492,4 +504,4 @@ CM_RT_API int32_t CmTaskRT::AddConditionalEnd(
 
     return hr;
 }
-}
+}  // namespace CMRT_UMD
