@@ -47,6 +47,20 @@ public:
     {
     }
 
+    //!
+    //! \brief    Set auxiliary resource
+    //! \details  Set auxiliary resource to sync with decompression
+    //! \param    [in] resource
+    //!           The resource will be used to sync
+    //!
+    //! \return   void
+    //!
+    void SetDecompSyncRes(
+        MOS_RESOURCE_HANDLE syncResource)
+    {
+        m_syncResource = syncResource;
+    }
+
     //!
     //! \brief    Media memory decompression
     //! \details  Entry point to decompress media memory
@@ -94,6 +108,8 @@ public:
     //!            The offset of copied surface from
     //! \param    [in] copyOutputOffset
     //!            The offset of copied to
+    //! \param    [in] bpp
+    //!            bit per pixel for copied surfaces
     //! \param    [in] bOutputCompressed
     //!            true means apply compression on output surface, else output uncompressed surface
     //!
@@ -106,11 +122,55 @@ public:
         uint32_t      copyHeight,
         uint32_t      copyInputOffset,
         uint32_t      copyOutputOffset,
+        uint32_t      bpp,
         bool          bOutputCompressed)
     {
         return MOS_STATUS_SUCCESS;
     }
 
+    //!
+    //! \brief    Media memory tile convert
+    //! \details  Convert media between Tile/Linear with decompression
+    //! \param    [in] inputSurface
+    //!            The source surface resource
+    //! \param    [out] outputSurface
+    //!            The target surface resource will be copied to
+    //! \param    [in] copyWidth
+    //!            The 2D surface Width
+    //! \param    [in] copyHeight
+    //!            The 2D surface height
+    //! \param    [in] copyInputOffset
+    //!            The offset of copied surface from
+    //! \param    [in] copyOutputOffset
+    //!            The offset of copied to
+    //! \param    [in] isTileToLinear
+    //!            Convertion direction, true: tile->linear, false: linear->tile
+    //! \param    [in] outputCompressed
+    //!            true means apply compression on output surface, else output uncompressed surface
+    //!
+    //! \return   MOS_STATUS_SUCCESS if succeeded, else error code.
+    //!
+    virtual MOS_STATUS MediaMemoryTileConvert(
+        PMOS_RESOURCE inputResource,
+        PMOS_RESOURCE outputResource,
+        uint32_t      copyWidth,
+        uint32_t      copyHeight,
+        uint32_t      copyInputOffset,
+        uint32_t      copyOutputOffset,
+        bool          isTileToLinear,
+        bool          outputCompressed)
+    {
+        return MOS_STATUS_UNIMPLEMENTED;
+    }
+
+    //!
+    //! \brief    GetDecompState's mosinterface
+    //! \details  get the mosinterface
+    //! \return   mosinterface
+    //!
+    virtual PMOS_INTERFACE GetDecompStateMosInterface() = 0;
+
+    MOS_RESOURCE_HANDLE    m_syncResource               = nullptr;   //!> Auxiliary resource to sync with decompression
 };
 
 #endif // __MEDIAMEMORYDECOMP_H__
