@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021, Intel Corporation
+* Copyright (c) 2021-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -38,6 +38,10 @@ std::shared_ptr<MediaUserSetting> MediaUserSetting::m_instance = nullptr;
 
 MediaUserSetting::MediaUserSetting()
 {
+}
+MediaUserSetting::MediaUserSetting(MOS_USER_FEATURE_KEY_PATH_INFO *keyPathInfo) : m_configure(keyPathInfo)
+{
+
 }
 
 void MediaUserSetting::Destroy()
@@ -66,7 +70,9 @@ MOS_STATUS MediaUserSetting::Register(
     const Value &defaultValue,
     bool isReportKey,
     bool debugOnly,
-    const std::string &customPath)
+    bool useCustomPath,
+    const std::string &customPath,
+    bool statePath)
 {
     return m_configure.Register(
                     valueName,
@@ -74,27 +80,27 @@ MOS_STATUS MediaUserSetting::Register(
                     defaultValue,
                     isReportKey,
                     debugOnly,
-                    customPath);
+                    useCustomPath,
+                    customPath,
+                    statePath);
 }
 
 MOS_STATUS MediaUserSetting::Read(Value &value,
     const std::string &valueName,
     const Group &group,
-    PMOS_CONTEXT mosContext,
     const Value &customValue,
     bool useCustomValue)
 {
-    return m_configure.Read(value, valueName, group, mosContext, customValue, useCustomValue);
+    return m_configure.Read(value, valueName, group, customValue, useCustomValue);
 }
 
 MOS_STATUS MediaUserSetting::Write(
     const std::string &valueName,
     const Value &value,
     const Group &group,
-    PMOS_CONTEXT mosContext,
     bool isForReport)
 {
-    return m_configure.Write(valueName, value, group, mosContext, isForReport);
+    return m_configure.Write(valueName, value, group, isForReport);
 }
 
 bool MediaUserSetting::IsDeclaredUserSetting(const std::string &valueName)
@@ -103,3 +109,4 @@ bool MediaUserSetting::IsDeclaredUserSetting(const std::string &valueName)
 }
 
 }
+
