@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2018, Intel Corporation
+* Copyright (c) 2015-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -28,6 +28,7 @@
 #include "vphal_render_composite.h"
 #include "mos_os.h"
 #include "mos_solo_generic.h"
+#include "hal_oca_interface.h"
 
 extern const MEDIA_OBJECT_KA2_INLINE_DATA g_cInit_MEDIA_OBJECT_KA2_INLINE_DATA =
 {
@@ -367,7 +368,8 @@ MOS_STATUS VpHal_RndrCommonSetPowerMode(
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_SSEU_SETTING_OVERRIDE_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        pRenderHal->pOsInterface->pOsContext);
 
     if (UserFeatureData.u32Data != 0xDEADC0DE)
     {
@@ -403,6 +405,8 @@ finish:
 //!             Pointer to GPGPU walker parameters
 //! \param      [in] KernelID
 //!             VP Kernel ID
+//! \param      [in] bLastSubmission
+//!             Is last submission
 //! \return     MOS_STATUS
 //!
 MOS_STATUS VpHal_RndrCommonSubmitCommands(
@@ -411,20 +415,30 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
     bool                                bNullRendering,
     PMHW_WALKER_PARAMS                  pWalkerParams,
     PMHW_GPGPU_WALKER_PARAMS            pGpGpuWalkerParams,
-    VpKernelID                          KernelID)
+    VpKernelID                          KernelID,
+    bool                                bLastSubmission)
 {
-    PMOS_INTERFACE                      pOsInterface;
-    MOS_COMMAND_BUFFER                  CmdBuffer;
-    MOS_STATUS                          eStatus;
-    uint32_t                            dwSyncTag;
-    int32_t                             i, iRemaining;
-    PMHW_MI_INTERFACE                   pMhwMiInterface;
-    MhwRenderInterface                  *pMhwRender;
-    MHW_MEDIA_STATE_FLUSH_PARAM         FlushParam;
-    bool                                bEnableSLM;
+    PMOS_INTERFACE                      pOsInterface = nullptr;
+    MOS_COMMAND_BUFFER                  CmdBuffer = {};
+    MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
+    uint32_t                            dwSyncTag = 0;
+    int32_t                             i = 0, iRemaining = 0;
+    PMHW_MI_INTERFACE                   pMhwMiInterface = nullptr;
+    MhwRenderInterface                  *pMhwRender = nullptr;
+    MHW_MEDIA_STATE_FLUSH_PARAM         FlushParam = {};
+    bool                                bEnableSLM = false;
     RENDERHAL_GENERIC_PROLOG_PARAMS     GenericPrologParams = {};
-    MOS_RESOURCE                        GpuStatusBuffer;
-    MediaPerfProfiler                   *pPerfProfiler;
+    PMOS_RESOURCE                       gpuStatusBuffer = nullptr;
+    MediaPerfProfiler                   *pPerfProfiler = nullptr;
+    MOS_CONTEXT                         *pOsContext = nullptr;
+    PMHW_MI_MMIOREGISTERS               pMmioRegisters = nullptr;
+
+    MHW_RENDERHAL_CHK_NULL(pRenderHal);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwMiInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface->GetMmioRegisters());
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface->pOsContext);
 
     eStatus             = MOS_STATUS_UNKNOWN;
     pOsInterface        = pRenderHal->pOsInterface;
@@ -434,6 +448,8 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
     FlushParam          = g_cRenderHal_InitMediaStateFlushParams;
     MOS_ZeroMemory(&CmdBuffer, sizeof(CmdBuffer));
     pPerfProfiler       = pRenderHal->pPerfProfiler;
+    pOsContext          = pOsInterface->pOsContext;
+    pMmioRegisters      = pMhwRender->GetMmioRegisters();
 
     // Allocate all available space, unused buffer will be returned later
     VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnGetCommandBuffer(pOsInterface, &CmdBuffer, 0));
@@ -446,16 +462,16 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
         KernelID));
 
 #ifndef EMUL
-    if (pOsInterface->bEnableKmdMediaFrameTracking)
+    if (bLastSubmission && pOsInterface->bEnableKmdMediaFrameTracking)
     {
         // Get GPU Status buffer
-        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnGetGpuStatusBufferResource(pOsInterface, &GpuStatusBuffer));
-
+        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnGetGpuStatusBufferResource(pOsInterface, gpuStatusBuffer));
+        VPHAL_RENDER_CHK_NULL(gpuStatusBuffer);
         // Register the buffer
-        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnRegisterResource(pOsInterface, &GpuStatusBuffer, true, true));
+        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnRegisterResource(pOsInterface, gpuStatusBuffer, true, true));
 
         GenericPrologParams.bEnableMediaFrameTracking = true;
-        GenericPrologParams.presMediaFrameTrackingSurface = &GpuStatusBuffer;
+        GenericPrologParams.presMediaFrameTrackingSurface  = gpuStatusBuffer;
         GenericPrologParams.dwMediaFrameTrackingTag = pOsInterface->pfnGetGpuStatusTag(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
         GenericPrologParams.dwMediaFrameTrackingAddrOffset = pOsInterface->pfnGetGpuStatusTagOffset(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
 
@@ -464,12 +480,23 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
     }
 #endif
 
+    HalOcaInterface::On1stLevelBBStart(CmdBuffer, *pOsContext, pOsInterface->CurrentGpuContextHandle,
+        *pRenderHal->pMhwMiInterface, *pMmioRegisters);
+
+    // Add kernel info to log.
+    HalOcaInterface::DumpVpKernelInfo(CmdBuffer, *pOsContext, KernelID, 0, nullptr);
+    // Add vphal param to log.
+    HalOcaInterface::DumpVphalParam(CmdBuffer, *pOsContext, pRenderHal->pVphalOcaDumper);
+
     // Initialize command buffer and insert prolog
     VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnInitCommandBuffer(pRenderHal, &CmdBuffer, &GenericPrologParams));
+
     // Write timing data for 3P budget
     VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendTimingData(pRenderHal, &CmdBuffer, true));
     VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectStartCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
+    VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+
     bEnableSLM = (pGpGpuWalkerParams && pGpGpuWalkerParams->SLMSize > 0)? true : false;
     VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSetCacheOverrideParams(
         pRenderHal,
@@ -492,6 +519,8 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
             false,
             true));
 
+        HalOcaInterface::OnSubLevelBBStart(CmdBuffer, *pOsContext, &pBatchBuffer->OsResource, 0, true, 0);
+
         // Send Start 2nd level batch buffer command (HW/OS dependent)
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferStartCmd(
             &CmdBuffer,
@@ -504,6 +533,8 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
         VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendRcsStatusTag(pRenderHal, &CmdBuffer));
     }
 
+    VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+
     VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectEndCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
     // Write timing data for 3P budget
@@ -550,6 +581,8 @@ MOS_STATUS VpHal_RndrCommonSubmitCommands(
         }
     }
 
+    HalOcaInterface::On1stLevelBBEnd(CmdBuffer, *pOsInterface);
+
     if (pBatchBuffer)
     {
         // Send Batch Buffer end command (HW/OS dependent)
@@ -608,7 +641,10 @@ finish:
             CmdBuffer.pCmdBase + CmdBuffer.iOffset / sizeof(uint32_t);
 
         // Return unused command buffer space to OS
-        pOsInterface->pfnReturnCommandBuffer(pOsInterface, &CmdBuffer, 0);
+        if (pOsInterface)
+        {
+            pOsInterface->pfnReturnCommandBuffer(pOsInterface, &CmdBuffer, 0);
+        }
     }
 
     return eStatus;
@@ -631,6 +667,12 @@ finish:
 //!             Pointer to pStatusTableUpdateParams
 //! \param      [in] KernelID
 //!             VP Kernel ID
+//! \param      [in] FcKernelCount
+//!             VP FC Kernel Count
+//! \param      [in] FcKernelList
+//!             VP FC Kernel List
+//! \param      [in] bLastSubmission
+//!             Is last submission
 //! \return     MOS_STATUS
 //!
 MOS_STATUS VpHal_RndrSubmitCommands(
@@ -640,20 +682,32 @@ MOS_STATUS VpHal_RndrSubmitCommands(
     PMHW_WALKER_PARAMS                  pWalkerParams,
     PMHW_GPGPU_WALKER_PARAMS            pGpGpuWalkerParams,
     PSTATUS_TABLE_UPDATE_PARAMS         pStatusTableUpdateParams,
-    VpKernelID                          KernelID)
+    VpKernelID                          KernelID,
+    int                                 FcKernelCount,
+    int                                 *FcKernelList,
+    bool                                bLastSubmission)
 {
-    PMOS_INTERFACE                      pOsInterface;
-    MOS_COMMAND_BUFFER                  CmdBuffer;
-    MOS_STATUS                          eStatus;
-    uint32_t                            dwSyncTag;
-    int32_t                             i, iRemaining;
-    PMHW_MI_INTERFACE                   pMhwMiInterface;
-    MhwRenderInterface                  *pMhwRender;
-    MHW_MEDIA_STATE_FLUSH_PARAM         FlushParam;
-    bool                                bEnableSLM;
+    PMOS_INTERFACE                      pOsInterface = nullptr;
+    MOS_COMMAND_BUFFER                  CmdBuffer = {};
+    MOS_STATUS                          eStatus = MOS_STATUS_SUCCESS;
+    uint32_t                            dwSyncTag = 0;
+    int32_t                             i = 0, iRemaining = 0;
+    PMHW_MI_INTERFACE                   pMhwMiInterface = nullptr;
+    MhwRenderInterface                  *pMhwRender = nullptr;
+    MHW_MEDIA_STATE_FLUSH_PARAM         FlushParam = {};
+    bool                                bEnableSLM = false;
     RENDERHAL_GENERIC_PROLOG_PARAMS     GenericPrologParams = {};
-    MOS_RESOURCE                        GpuStatusBuffer;
-    MediaPerfProfiler                   *pPerfProfiler;
+    PMOS_RESOURCE                       gpuStatusBuffer = nullptr;
+    MediaPerfProfiler                   *pPerfProfiler = nullptr;
+    MOS_CONTEXT                         *pOsContext = nullptr;
+    PMHW_MI_MMIOREGISTERS               pMmioRegisters = nullptr;
+
+    MHW_RENDERHAL_CHK_NULL(pRenderHal);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwMiInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface->GetMmioRegisters());
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface);
+    MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface->pOsContext);
 
     eStatus              = MOS_STATUS_UNKNOWN;
     pOsInterface         = pRenderHal->pOsInterface;
@@ -663,6 +717,8 @@ MOS_STATUS VpHal_RndrSubmitCommands(
     FlushParam           = g_cRenderHal_InitMediaStateFlushParams;
     MOS_ZeroMemory(&CmdBuffer, sizeof(CmdBuffer));
     pPerfProfiler       = pRenderHal->pPerfProfiler;
+    pOsContext          = pOsInterface->pOsContext;
+    pMmioRegisters      = pMhwRender->GetMmioRegisters();
 
     // Allocate all available space, unused buffer will be returned later
     VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnGetCommandBuffer(pOsInterface, &CmdBuffer, 0));
@@ -675,16 +731,17 @@ MOS_STATUS VpHal_RndrSubmitCommands(
         KernelID));
 
 #ifndef EMUL
-    if (pOsInterface->bEnableKmdMediaFrameTracking)
+    if (bLastSubmission && pOsInterface->bEnableKmdMediaFrameTracking)
     {
         // Get GPU Status buffer
-        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnGetGpuStatusBufferResource(pOsInterface, &GpuStatusBuffer));
+        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnGetGpuStatusBufferResource(pOsInterface, gpuStatusBuffer));
+        VPHAL_RENDER_CHK_NULL(gpuStatusBuffer);
 
         // Register the buffer
-        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnRegisterResource(pOsInterface, &GpuStatusBuffer, true, true));
+        VPHAL_RENDER_CHK_STATUS(pOsInterface->pfnRegisterResource(pOsInterface, gpuStatusBuffer, true, true));
 
         GenericPrologParams.bEnableMediaFrameTracking = true;
-        GenericPrologParams.presMediaFrameTrackingSurface = &GpuStatusBuffer;
+        GenericPrologParams.presMediaFrameTrackingSurface = gpuStatusBuffer;
         GenericPrologParams.dwMediaFrameTrackingTag = pOsInterface->pfnGetGpuStatusTag(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
         GenericPrologParams.dwMediaFrameTrackingAddrOffset = pOsInterface->pfnGetGpuStatusTagOffset(pOsInterface, pOsInterface->CurrentGpuContextOrdinal);
 
@@ -693,11 +750,21 @@ MOS_STATUS VpHal_RndrSubmitCommands(
     }
 #endif
 
+    HalOcaInterface::On1stLevelBBStart(CmdBuffer, *pOsContext, pOsInterface->CurrentGpuContextHandle,
+        *pRenderHal->pMhwMiInterface, *pMmioRegisters);
+
+    // Add kernel info to log.
+    HalOcaInterface::DumpVpKernelInfo(CmdBuffer, *pOsContext, KernelID, FcKernelCount, FcKernelList);
+    // Add vphal param to log.
+    HalOcaInterface::DumpVphalParam(CmdBuffer, *pOsContext, pRenderHal->pVphalOcaDumper);
+
     // Initialize command buffer and insert prolog
     VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnInitCommandBuffer(pRenderHal, &CmdBuffer, &GenericPrologParams));
 
     VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectStartCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
+    VPHAL_RENDER_CHK_STATUS(NullHW::StartPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+
     // Write timing data for 3P budget
     VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendTimingData(pRenderHal, &CmdBuffer, true));
 
@@ -731,6 +798,8 @@ MOS_STATUS VpHal_RndrSubmitCommands(
             false,
             true));
 
+        HalOcaInterface::OnSubLevelBBStart(CmdBuffer, *pOsContext, &pBatchBuffer->OsResource, 0, true, 0);
+
         // Send Start 2nd level batch buffer command (HW/OS dependent)
         VPHAL_RENDER_CHK_STATUS(pMhwMiInterface->AddMiBatchBufferStartCmd(
             &CmdBuffer,
@@ -743,6 +812,8 @@ MOS_STATUS VpHal_RndrSubmitCommands(
         VPHAL_RENDER_CHK_STATUS(pRenderHal->pfnSendRcsStatusTag(pRenderHal, &CmdBuffer));
     }
 
+    VPHAL_RENDER_CHK_STATUS(NullHW::StopPredicate(pRenderHal->pMhwMiInterface, &CmdBuffer));
+
     VPHAL_RENDER_CHK_STATUS(pPerfProfiler->AddPerfCollectEndCmd((void*)pRenderHal, pOsInterface, pMhwMiInterface, &CmdBuffer));
 
     // Write timing data for 3P budget
@@ -789,6 +860,8 @@ MOS_STATUS VpHal_RndrSubmitCommands(
         }
     }
 
+    HalOcaInterface::On1stLevelBBEnd(CmdBuffer, *pOsInterface);
+
     if (pBatchBuffer)
     {
         // Send Batch Buffer end command (HW/OS dependent)
@@ -840,7 +913,7 @@ MOS_STATUS VpHal_RndrSubmitCommands(
 
 finish:
 
-    if (pStatusTableUpdateParams)
+    if (pStatusTableUpdateParams && pOsInterface)
     {
         VpHal_RndrUpdateStatusTableAfterSubmit(pOsInterface, pStatusTableUpdateParams, pOsInterface->CurrentGpuContextOrdinal, eStatus);
     }
@@ -862,7 +935,10 @@ finish:
             CmdBuffer.pCmdBase + CmdBuffer.iOffset / sizeof(uint32_t);
 
         // Return unused command buffer space to OS
-        pOsInterface->pfnReturnCommandBuffer(pOsInterface, &CmdBuffer, 0);
+        if (pOsInterface)
+        {
+            pOsInterface->pfnReturnCommandBuffer(pOsInterface, &CmdBuffer, 0);
+        }
     }
 
     return eStatus;
@@ -895,6 +971,8 @@ MOS_STATUS VpHal_RndrCommonInitRenderHalSurface(
     pRenderHalSurface->OsSurface.dwPitch            = pVpSurface->dwPitch;
     pRenderHalSurface->OsSurface.Format             = pVpSurface->Format;
     pRenderHalSurface->OsSurface.TileType           = pVpSurface->TileType;
+    pRenderHalSurface->OsSurface.TileModeGMM        = pVpSurface->TileModeGMM;
+    pRenderHalSurface->OsSurface.bGMMTileEnabled    = pVpSurface->bGMMTileEnabled;
     pRenderHalSurface->OsSurface.dwOffset           = pVpSurface->dwOffset;
     pRenderHalSurface->OsSurface.bIsCompressed      = pVpSurface->bIsCompressed;
     pRenderHalSurface->OsSurface.bCompressible      = pVpSurface->bCompressible;
@@ -902,6 +980,7 @@ MOS_STATUS VpHal_RndrCommonInitRenderHalSurface(
     pRenderHalSurface->OsSurface.dwDepth            = pVpSurface->dwDepth;
     pRenderHalSurface->OsSurface.dwQPitch           = pVpSurface->dwHeight;
     pRenderHalSurface->OsSurface.MmcState           = (MOS_MEMCOMP_STATE)pVpSurface->CompressionMode;
+    pRenderHalSurface->OsSurface.CompressionFormat  = pVpSurface->CompressionFormat;
 
     VpHal_RndrInitPlaneOffset(
         &pRenderHalSurface->OsSurface.YPlaneOffset,
@@ -1100,6 +1179,9 @@ MOS_STATUS VpHal_RndrCommonSetBufferSurfaceForHwAccess(
     PRENDERHAL_SURFACE_STATE_ENTRY      pSurfaceEntry;
     MOS_STATUS                          eStatus;
 
+    VPHAL_RENDER_CHK_NULL(pRenderHal);
+    VPHAL_RENDER_CHK_NULL(pRenderHal->pOsInterface);
+
     // Initialize Variables
     eStatus                         = MOS_STATUS_SUCCESS;
     pOsInterface                    = pRenderHal->pOsInterface;
@@ -1121,6 +1203,12 @@ MOS_STATUS VpHal_RndrCommonSetBufferSurfaceForHwAccess(
     if (pSurfaceParams == nullptr)
     {
         MOS_ZeroMemory(&SurfaceParam, sizeof(SurfaceParam));
+
+        //set mem object control for cache
+        SurfaceParam.MemObjCtl = (pRenderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
+            MOS_MP_RESOURCE_USAGE_DEFAULT,
+            pRenderHal->pOsInterface->pfnGetGmmClientContext(pRenderHal->pOsInterface))).DwordValue;
+
         pSurfaceParams = &SurfaceParam;
     }
 
@@ -1260,6 +1348,9 @@ MOS_STATUS VpHal_CommonSetBufferSurfaceForHwAccess(
     PRENDERHAL_SURFACE_STATE_ENTRY      pSurfaceEntry;
     MOS_STATUS                          eStatus;
 
+    VPHAL_RENDER_CHK_NULL(pRenderHal);
+    VPHAL_RENDER_CHK_NULL(pRenderHal->pOsInterface);
+
     // Initialize Variables
     eStatus                         = MOS_STATUS_SUCCESS;
     pOsInterface                    = pRenderHal->pOsInterface;
@@ -1276,6 +1367,12 @@ MOS_STATUS VpHal_CommonSetBufferSurfaceForHwAccess(
     if (pSurfaceParams == nullptr)
     {
         MOS_ZeroMemory(&SurfaceParam, sizeof(SurfaceParam));
+
+        //set mem object control for cache
+        SurfaceParam.MemObjCtl = (pRenderHal->pOsInterface->pfnCachePolicyGetMemoryObject(
+            MOS_MP_RESOURCE_USAGE_DEFAULT,
+            pRenderHal->pOsInterface->pfnGetGmmClientContext(pRenderHal->pOsInterface))).DwordValue;
+
         pSurfaceParams = &SurfaceParam;
     }
 
@@ -1330,6 +1427,8 @@ bool VpHal_RndrCommonIsAlignmentWANeeded(
         case MOS_GPU_CONTEXT_RENDER3:
         case MOS_GPU_CONTEXT_RENDER4:
         case MOS_GPU_CONTEXT_COMPUTE:
+        case MOS_GPU_CONTEXT_COMPUTE_RA:
+        case MOS_GPU_CONTEXT_RENDER_RA:
             if (!(MOS_IS_ALIGNED(MOS_MIN((uint32_t)pSurface->dwHeight, (uint32_t)pSurface->rcMaxSrc.bottom), 4)) &&
                 (pSurface->Format == Format_NV12))
             {
@@ -1615,6 +1714,17 @@ MOS_STATUS VpHal_RndrUpdateStatusTableAfterSubmit(
     pStatusEntry->dwStatus          = (eLastStatus == MOS_STATUS_SUCCESS)? VPREP_NOTREADY : VPREP_ERROR;
     pStatusTable->uiCurrent         = (pStatusTable->uiCurrent + 1) & (VPHAL_STATUS_TABLE_MAX_SIZE - 1);
 
+    // CM may use a different streamIndex, record it here
+    if (pStatusTableUpdateParams->bUpdateStreamIndex)
+    {
+        pStatusEntry->isStreamIndexSet = true;
+        pStatusEntry->streamIndex = (uint16_t)pOsInterface->streamIndex;
+    }
+    else
+    {
+        pStatusEntry->isStreamIndexSet = false;
+    }
+
 finish:
     return eStatus;
 }
