@@ -1387,6 +1387,7 @@ MOS_STATUS VphalRenderer::Initialize(
     //---------------------------------------
     m_isApoEnabled     = isApoEnabled;
     m_renderGpuContext = m_pOsInterface->pfnGetGpuContext(m_pOsInterface);
+    m_clearVideoViewMode = pSettings->clearVideoViewMode;
 
     Align16State.pPerfData   = &PerfData;
     Fast1toNState.pPerfData  = &PerfData;
@@ -1448,39 +1449,42 @@ MOS_STATUS VphalRenderer::Initialize(
         }
     }
 
-    VeboxExecState[0].Mode               = VEBOX_EXEC_MODE_0;
-    VeboxExecState[0].bDIOutputPair01    = true;
-    VeboxExecState[0].bSpeculativeCopy   = false;
-    VeboxExecState[0].bEnable            = (pSettings->veboxParallelExecution == VEBOX_EXECUTION_OVERRIDE_ENABLE);
-    VeboxExecState[1]                    = VeboxExecState[0];
-
-    // Initialize VEBOX renderer
-    VPHAL_RENDER_CHK_STATUS(pRender[VPHAL_RENDER_ID_VEBOX]->Initialize(
-           pSettings,
-           pKernelDllState));
-
-    VPHAL_RENDER_CHK_STATUS(pRender[VPHAL_RENDER_ID_VEBOX2]->Initialize(
-           pSettings,
-           pKernelDllState));
-
     // Initialize Compositing renderer
     VPHAL_RENDER_CHK_STATUS(pRender[VPHAL_RENDER_ID_COMPOSITE]->Initialize(
         pSettings,
         pKernelDllState));
 
-    // Initialize 16 Alignment Interface and renderer
-    VpHal_16AlignInitInterface(&Align16State, m_pRenderHal);
-    VPHAL_RENDER_CHK_STATUS(Align16State.pfnInitialize(
-           &Align16State,
-           pSettings,
-           pKernelDllState))
+    if (!m_clearVideoViewMode)
+    {
+        VeboxExecState[0].Mode             = VEBOX_EXEC_MODE_0;
+        VeboxExecState[0].bDIOutputPair01  = true;
+        VeboxExecState[0].bSpeculativeCopy = false;
+        VeboxExecState[0].bEnable          = (pSettings->veboxParallelExecution == VEBOX_EXECUTION_OVERRIDE_ENABLE);
+        VeboxExecState[1]                  = VeboxExecState[0];
 
-    // Initialize fast 1to N Interface and render
-    VpHal_Fast1toNInitInterface(&Fast1toNState, m_pRenderHal);
-    VPHAL_RENDER_CHK_STATUS(Fast1toNState.pfnInitialize(
-           &Fast1toNState,
-           pSettings,
-           pKernelDllState))
+        // Initialize VEBOX renderer
+        VPHAL_RENDER_CHK_STATUS(pRender[VPHAL_RENDER_ID_VEBOX]->Initialize(
+            pSettings,
+            pKernelDllState));
+
+        VPHAL_RENDER_CHK_STATUS(pRender[VPHAL_RENDER_ID_VEBOX2]->Initialize(
+            pSettings,
+            pKernelDllState));
+
+        // Initialize 16 Alignment Interface and renderer
+        VpHal_16AlignInitInterface(&Align16State, m_pRenderHal);
+        VPHAL_RENDER_CHK_STATUS(Align16State.pfnInitialize(
+            &Align16State,
+            pSettings,
+            pKernelDllState))
+
+        // Initialize fast 1to N Interface and render
+        VpHal_Fast1toNInitInterface(&Fast1toNState, m_pRenderHal);
+        VPHAL_RENDER_CHK_STATUS(Fast1toNState.pfnInitialize(
+            &Fast1toNState,
+            pSettings,
+            pKernelDllState))
+    }
 
     eStatus = AllocateDebugDumper();
     if (eStatus != MOS_STATUS_SUCCESS)
@@ -1499,7 +1503,7 @@ MOS_STATUS VphalRenderer::Initialize(
     }
 
     // Initialize Hdr renderer
-    if (MEDIA_IS_SKU(m_pSkuTable, FtrHDR) && pHdrState)
+    if (MEDIA_IS_SKU(m_pSkuTable, FtrHDR) && pHdrState && !m_clearVideoViewMode)
     {
         VPHAL_RENDER_CHK_STATUS(pHdrState->pfnInitialize(
             pHdrState,
@@ -1508,7 +1512,6 @@ MOS_STATUS VphalRenderer::Initialize(
     }
 
     eStatus = MOS_STATUS_SUCCESS;
-
 finish:
     if (eStatus != MOS_STATUS_SUCCESS)
     {
