@@ -62,10 +62,10 @@ MOS_STATUS MhwSfcInterfaceG11::AddSfcState(
     wVYOffset           = 0;
 
     // Check input/output size
-    MHW_ASSERT(pSfcStateParams->dwInputFrameWidth   >= MHW_SFC_MIN_WIDTH);
-    MHW_ASSERT(pSfcStateParams->dwInputFrameHeight  >= MHW_SFC_MIN_HEIGHT);
-    MHW_ASSERT(pSfcStateParams->dwOutputFrameWidth  <= MHW_SFC_MAX_WIDTH);
-    MHW_ASSERT(pSfcStateParams->dwOutputFrameHeight <= MHW_SFC_MAX_HEIGHT);
+    MHW_ASSERT(pSfcStateParams->dwInputFrameWidth   >= m_minWidth);
+    MHW_ASSERT(pSfcStateParams->dwInputFrameHeight  >= m_minHeight);
+    MHW_ASSERT(pSfcStateParams->dwOutputFrameWidth  <= m_maxWidth);
+    MHW_ASSERT(pSfcStateParams->dwOutputFrameHeight <= m_maxHeight);
 
     // Set DW1
     cmd.DW1.SfcPipeMode                  = pSfcStateParams->sfcPipeMode;
@@ -292,6 +292,7 @@ MOS_STATUS MhwSfcInterfaceG11::AddSfcAvsState(
     PMHW_SFC_AVS_STATE              pSfcAvsState)
 {
     MHW_CHK_NULL_RETURN(pCmdBuffer);
+    MHW_CHK_NULL_RETURN(pSfcAvsState);
 
     mhw_sfc_g11_X::SFC_AVS_STATE_CMD *cmdPtr;
     cmdPtr = (mhw_sfc_g11_X::SFC_AVS_STATE_CMD *)pCmdBuffer->pCmdPtr;
@@ -372,8 +373,7 @@ MOS_STATUS MhwSfcInterfaceG11::SetSfcSamplerTable(
 
         pAvsParams->fScaleX = fScaleX;
 
-        // For 1x scaling in horizontal direction and not force polyphase coefs, use special coefficients for filtering
-        if (fScaleX == 1.0F && !pAvsParams->bForcePolyPhaseCoefs)
+        if (m_scalingMode == MHW_SCALING_NEAREST)
         {
             MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
                 piYCoefsX,
@@ -387,36 +387,52 @@ MOS_STATUS MhwSfcInterfaceG11::SetSfcSamplerTable(
         }
         else
         {
-            // Clamp the Scaling Factor if > 1.0x
-            fScaleX = MOS_MIN(1.0F, fScaleX);
+            // For 1x scaling in horizontal direction and not force polyphase coefs, use special coefficients for filtering
+            if ((fScaleX == 1.0F && !pAvsParams->bForcePolyPhaseCoefs))
+            {
+                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                    piYCoefsX,
+                    Plane,
+                    true));
 
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
-                piYCoefsX,
-                fScaleX,
-                Plane,
-                SrcFormat,
-                fHPStrength,
-                bUse8x8Filter,
-                NUM_HW_POLYPHASE_TABLES,
-                0));
-        }
+                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                    piUVCoefsX,
+                    MHW_U_PLANE,
+                    true));
+            }
+            else
+            {
+                // Clamp the Scaling Factor if > 1.0x
+                fScaleX = MOS_MIN(1.0F, fScaleX);
 
-        // If Chroma Siting info is present
-        if (dwChromaSiting & MHW_CHROMA_SITING_HORZ_LEFT)
-        {
-            // No Chroma Siting
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                piUVCoefsX,
-                2.0F,
-                fScaleX));
-        }
-        else
-        {
-            // Chroma siting offset will be add in the HW cmd
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                piUVCoefsX,
-                3.0F,
-                fScaleX));
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
+                    piYCoefsX,
+                    fScaleX,
+                    Plane,
+                    SrcFormat,
+                    fHPStrength,
+                    bUse8x8Filter,
+                    NUM_HW_POLYPHASE_TABLES,
+                    0));
+            }
+
+            // If Chroma Siting info is present
+            if (dwChromaSiting & MHW_CHROMA_SITING_HORZ_LEFT)
+            {
+                // No Chroma Siting
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                    piUVCoefsX,
+                    2.0F,
+                    fScaleX));
+            }
+            else
+            {
+                // Chroma siting offset will be add in the HW cmd
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                    piUVCoefsX,
+                    3.0F,
+                    fScaleX));
+            }
         }
     }
 
@@ -432,8 +448,7 @@ MOS_STATUS MhwSfcInterfaceG11::SetSfcSamplerTable(
 
         pAvsParams->fScaleY = fScaleY;
 
-        // For 1x scaling in vertical direction and not force polyphase coefs, use special coefficients for filtering
-        if (fScaleY == 1.0F && !pAvsParams->bForcePolyPhaseCoefs)
+        if (m_scalingMode == MHW_SCALING_NEAREST)
         {
             MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
                 piYCoefsY,
@@ -447,35 +462,51 @@ MOS_STATUS MhwSfcInterfaceG11::SetSfcSamplerTable(
         }
         else
         {
-            // Clamp the Scaling Factor if > 1.0x
-            fScaleY = MOS_MIN(1.0F, fScaleY);
+            // For 1x scaling in vertical direction and not force polyphase coefs, use special coefficients for filtering
+            if ((fScaleY == 1.0F && !pAvsParams->bForcePolyPhaseCoefs))
+            {
+                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                    piYCoefsY,
+                    Plane,
+                    true));
 
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
-                piYCoefsY,
-                fScaleY,
-                Plane,
-                SrcFormat,
-                fHPStrength,
-                bUse8x8Filter,
-                NUM_HW_POLYPHASE_TABLES,0));
-        }
+                MHW_CHK_STATUS_RETURN(Mhw_SetNearestModeTable(
+                    piUVCoefsY,
+                    MHW_U_PLANE,
+                    true));
+            }
+            else
+            {
+                // Clamp the Scaling Factor if > 1.0x
+                fScaleY = MOS_MIN(1.0F, fScaleY);
 
-        // If Chroma Siting info is present
-        if (dwChromaSiting & MHW_CHROMA_SITING_VERT_TOP)
-        {
-            // No Chroma Siting
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                piUVCoefsY,
-                2.0F,
-                fScaleY));
-        }
-        else
-        {
-            // Chroma siting offset will be add in the HW cmd
-            MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
-                piUVCoefsY,
-                3.0F,
-                fScaleY));
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesY(
+                    piYCoefsY,
+                    fScaleY,
+                    Plane,
+                    SrcFormat,
+                    fHPStrength,
+                    bUse8x8Filter,
+                    NUM_HW_POLYPHASE_TABLES, 0));
+            }
+
+            // If Chroma Siting info is present
+            if (dwChromaSiting & MHW_CHROMA_SITING_VERT_TOP)
+            {
+                // No Chroma Siting
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                    piUVCoefsY,
+                    2.0F,
+                    fScaleY));
+            }
+            else
+            {
+                // Chroma siting offset will be add in the HW cmd
+                MHW_CHK_STATUS_RETURN(Mhw_CalcPolyphaseTablesUV(
+                    piUVCoefsY,
+                    3.0F,
+                    fScaleY));
+            }
         }
     }
 
