@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2020, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -42,6 +42,24 @@ MOS_STATUS CodechalDecodeAvcG12::AllocateStandard(
     CODECHAL_DECODE_CHK_NULL_RETURN(settings);
 
     CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeAvc::AllocateStandard(settings));
+#ifdef _MMC_SUPPORTED
+    // To WA invalid aux data caused HW issue when MMC on
+    // Add disable Clear CCS WA due to green corruption issue
+    if (m_mmc->IsMmcEnabled())
+    {
+        if (MEDIA_IS_WA(m_waTable, Wa_1408785368) || MEDIA_IS_WA(m_waTable, Wa_22010493002) && (!MEDIA_IS_WA(m_waTable, WaDisableClearCCS)))
+        {
+            //Add HUC STATE Commands
+            MHW_VDBOX_STATE_CMDSIZE_PARAMS stateCmdSizeParams;
+
+            m_hwInterface->GetHucStateCommandSize(
+                CODECHAL_DECODE_MODE_AVCVLD,
+                &m_HucStateCmdBufferSizeNeeded,
+                &m_HucPatchListSizeNeeded,
+                &stateCmdSizeParams);
+        }
+    }
+#endif
 
     if ( MOS_VE_SUPPORTED(m_osInterface))
     {
@@ -162,19 +180,38 @@ MOS_STATUS CodechalDecodeAvcG12::AllocateHistogramSurface()
     return MOS_STATUS_SUCCESS;
 }
 
+void CodechalDecodeAvcG12::CalcRequestedSpace(
+    uint32_t &requestedSize,
+    uint32_t &additionalSizeNeeded,
+    uint32_t &requestedPatchListSize) 
+{  
+    CODECHAL_DECODE_FUNCTION_ENTER;
+
+    requestedSize          = m_commandBufferSizeNeeded + m_HucStateCmdBufferSizeNeeded +
+                    (m_standardDecodeSizeNeeded * (m_decodeParams.m_numSlices + 1));
+    requestedPatchListSize = m_commandPatchListSizeNeeded + m_HucPatchListSizeNeeded +
+                             (m_standardDecodePatchListSizeNeeded * (m_decodeParams.m_numSlices + 1));
+    additionalSizeNeeded = COMMAND_BUFFER_RESERVED_SPACE;
+
+}
+
 MOS_STATUS CodechalDecodeAvcG12::SetFrameStates()
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
+    if (m_secureDecoder)
+    {
+        m_secureDecoder->EnableSampleGroupConstantIV();
+    }
 
 #ifdef _DECODE_PROCESSING_SUPPORTED
     if (m_decodeParams.m_procParams)
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(AllocateHistogramSurface());
 
-        ((CODECHAL_DECODE_PROCESSING_PARAMS*)m_decodeParams.m_procParams)->pHistogramSurface = m_histogramSurface;
+        ((DecodeProcessingParams*)m_decodeParams.m_procParams)->m_histogramSurface = m_histogramSurface;
 
         if (m_decodeHistogram)
             m_decodeHistogram->SetSrcHistogramSurface(m_histogramSurface);
@@ -182,25 +219,6 @@ MOS_STATUS CodechalDecodeAvcG12::SetFrameStates()
     }
 #endif
 
-#ifdef _MMC_SUPPORTED
-    // To WA invalid aux data caused HW issue when MMC on
-    if (m_mmc && m_mmc->IsMmcEnabled() && MEDIA_IS_WA(m_waTable, Wa_1408785368) &&
-        m_decodeParams.m_destSurface && !Mos_ResourceIsNull(&m_decodeParams.m_destSurface->OsResource) &&
-        m_decodeParams.m_destSurface->OsResource.bConvertedFromDDIResource)
-    {
-        if (m_secureDecoder && m_secureDecoder->IsAuxDataInvalid(&m_decodeParams.m_destSurface->OsResource))
-        {
-            CODECHAL_DECODE_CHK_STATUS_RETURN(m_secureDecoder->InitAuxSurface(&m_decodeParams.m_destSurface->OsResource, false, true));
-        }
-        else
-        {
-            CODECHAL_DECODE_VERBOSEMESSAGE("Clear CCS by VE resolve before frame %d submission", m_frameNum);
-            CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnDecompResource(m_osInterface, &m_decodeParams.m_destSurface->OsResource));
-            CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(m_osInterface, m_videoContext));
-        }
-    }
-#endif
-
     CODECHAL_DECODE_CHK_STATUS_RETURN(CodechalDecodeAvc::SetFrameStates());
 
     if (MOS_VE_SUPPORTED(m_osInterface) && !MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(m_osInterface))
@@ -227,6 +245,29 @@ MOS_STATUS CodechalDecodeAvcG12::DecodeStateLevel()
 
     CODECHAL_DECODE_FUNCTION_ENTER;
 
+#ifdef _MMC_SUPPORTED
+    // To WA invalid aux data caused HW issue when MMC on
+    // Add disable Clear CCS WA due to green corruption issue
+    if (m_mmc->IsMmcEnabled() && m_decodeParams.m_destSurface && !Mos_ResourceIsNull(&m_decodeParams.m_destSurface->OsResource) &&
+        m_decodeParams.m_destSurface->OsResource.bConvertedFromDDIResource)
+    {
+        if (MEDIA_IS_WA(m_waTable, Wa_1408785368) || MEDIA_IS_WA(m_waTable, Wa_22010493002) && (!MEDIA_IS_WA(m_waTable, WaDisableClearCCS)))
+        {
+            if (m_secureDecoder && m_secureDecoder->IsAuxDataInvalid(&m_decodeParams.m_destSurface->OsResource))
+            {
+                CODECHAL_DECODE_CHK_STATUS_RETURN(m_secureDecoder->InitAuxSurface(&m_decodeParams.m_destSurface->OsResource, false, true));
+            }
+            else
+            {
+                CODECHAL_DECODE_VERBOSEMESSAGE("Clear CCS by VE resolve before frame %d submission", m_frameNum);
+                CODECHAL_DECODE_CHK_STATUS_RETURN(static_cast<CodecHalMmcStateG12 *>(m_mmc)->ClearAuxSurf(
+                    this, m_miInterface, &m_decodeParams.m_destSurface->OsResource, m_veState));
+            }
+        }
+
+    }
+#endif
+
     if (m_secureDecoder)
     {
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_secureDecoder->Execute(this));
@@ -366,6 +407,18 @@ MOS_STATUS CodechalDecodeAvcG12::DecodePrimitiveLevel()
         CODECHAL_DECODE_CHK_STATUS_RETURN(EndStatusReport(decodeStatusReport, &cmdBuffer));
     }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (CodecHal_PictureIsFrame(m_crrPic) ||
+        CodecHal_PictureIsInterlacedFrame(m_crrPic) ||
+        m_secondField)
+    {
+        uint32_t curIdx = (GetDecodeStatusBuf()->m_currIndex + CODECHAL_DECODE_STATUS_NUM - 1) % CODECHAL_DECODE_STATUS_NUM;
+        uint32_t frameCrcOffset = curIdx * sizeof(CodechalDecodeStatus) + GetDecodeStatusBuf()->m_decFrameCrcOffset + sizeof(uint32_t) * 2;
+        std::vector<MOS_RESOURCE> vSemaResource{GetDecodeStatusBuf()->m_statusBuffer};
+        m_debugInterface->DetectCorruptionHw(m_hwInterface, &m_frameCountTypeBuf, curIdx, frameCrcOffset, vSemaResource, &cmdBuffer, m_frameNum);
+    }
+#endif
+
     CODECHAL_DECODE_CHK_STATUS_RETURN(m_miInterface->AddMiBatchBufferEnd(&cmdBuffer, nullptr));
 
     m_osInterface->pfnReturnCommandBuffer(m_osInterface, &cmdBuffer, 0);
@@ -409,9 +462,20 @@ MOS_STATUS CodechalDecodeAvcG12::DecodePrimitiveLevel()
     CODECHAL_DEBUG_TOOL(
         m_mmc->UpdateUserFeatureKey(&m_destSurface);)
 #ifdef _DECODE_PROCESSING_SUPPORTED
-    auto decProcessingParams = (CODECHAL_DECODE_PROCESSING_PARAMS *)m_decodeParams.m_procParams;
+    auto decProcessingParams = (DecodeProcessingParams *)m_decodeParams.m_procParams;
     if (decProcessingParams != nullptr && !m_sfcState->m_sfcPipeOut && (m_isSecondField || m_avcPicParams->seq_fields.mb_adaptive_frame_field_flag))
     {
+#ifdef _MMC_SUPPORTED
+        // To Clear invalid aux data of output surface when MMC on
+        if (m_mmc && m_mmc->IsMmcEnabled() &&
+            !Mos_ResourceIsNull(&decProcessingParams->m_outputSurface->OsResource) &&
+            decProcessingParams->m_outputSurface->OsResource.bConvertedFromDDIResource)
+        {
+            CODECHAL_DECODE_VERBOSEMESSAGE("Clear invalid aux data of output surface before frame %d submission", m_frameNum);
+            CODECHAL_DECODE_CHK_STATUS_RETURN(static_cast<CodecHalMmcStateG12 *>(m_mmc)->ClearAuxSurf(
+                this, m_miInterface, &decProcessingParams->m_outputSurface->OsResource, m_veState));
+        }
+#endif
         CODECHAL_DECODE_CHK_STATUS_RETURN(m_fieldScalingInterface->DoFieldScaling(
             decProcessingParams,
             m_renderContext,
@@ -444,7 +508,7 @@ MOS_STATUS CodechalDecodeAvcG12::DecodePrimitiveLevel()
         {
             syncParams = g_cInitSyncParams;
             syncParams.GpuContext = m_renderContext;
-            syncParams.presSyncResource = &decProcessingParams->pOutputSurface->OsResource;
+            syncParams.presSyncResource = &decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceSignal(m_osInterface, &syncParams));
         }
@@ -453,12 +517,12 @@ MOS_STATUS CodechalDecodeAvcG12::DecodePrimitiveLevel()
 #ifdef _DECODE_PROCESSING_SUPPORTED
     CODECHAL_DEBUG_TOOL(
         // Dump out downsampling result
-        if (decProcessingParams && decProcessingParams->pOutputSurface)
+        if (decProcessingParams && decProcessingParams->m_outputSurface)
         {
             MOS_SURFACE dstSurface;
             MOS_ZeroMemory(&dstSurface, sizeof(dstSurface));
             dstSurface.Format = Format_NV12;
-            dstSurface.OsResource = decProcessingParams->pOutputSurface->OsResource;
+            dstSurface.OsResource = decProcessingParams->m_outputSurface->OsResource;
 
             CODECHAL_DECODE_CHK_STATUS_RETURN(CodecHalGetResourceInfo(
                 m_osInterface,
