@@ -56,9 +56,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID_G12
     __MEDIA_USER_FEATURE_VALUE_HEVC_VME_BREAK12_ID_G12,
     /* codec g12hp based */
     __MEDIA_USER_FEATURE_VALUE_HEVC_VME_ENABLE_RENDER_CONTEXT_ID_G12HP,
-    /* VP gen12 based */
-    __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_CENTERING_DISABLE_ID_G12,
-    __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_DTR_DISABLE_ID_G12,
     __MOS_USER_FEATURE_KEY_G12_MAX_ID,
 } MOS_USER_FEATURE_VALUE_ID_G12;
 
