@@ -1946,17 +1946,44 @@ MOS_STATUS MhwVeboxInterfaceG9::VeboxAdjustBoundary(
             break;
     }
 
-    // Align width and height with max src renctange with consideration of
-    // these conditions:
-    // The minimum of width/height should equal to or larger than
-    // MHW_VEBOX_MIN_WIDTH/HEIGHT. The maximum of width/heigh should equal
-    // to or smaller than surface width/height
-    *pdwSurfaceHeight = MOS_ALIGN_CEIL(
-        MOS_MIN(pSurfaceParam->dwHeight, MOS_MAX((uint32_t)pSurfaceParam->rcMaxSrc.bottom, MHW_VEBOX_MIN_HEIGHT)),
-        wHeightAlignUnit);
-    *pdwSurfaceWidth = MOS_ALIGN_CEIL(
-        MOS_MIN(pSurfaceParam->dwWidth, MOS_MAX((uint32_t)pSurfaceParam->rcMaxSrc.right, MHW_VEBOX_MIN_WIDTH)),
-        wWidthAlignUnit);
+    //When Crop being used in vebox, source surface height/width is updated in VeboxAdjustBoundary(), and the rcMaxSrc is used for crop rectangle.
+    //But in dynamic Crop case, if the rcMaxSrc is larger than the rcSrc, the input pdwSurfaceHeight/pdwSurfaceWidth will be the input surface size.
+    //And if the target surface size is smaller than input surface, it may lead to pagefault issue . So in Vebox Crop case, we set the pdwSurfaceHeight/pdwSurfaceWidth
+    //with rcSrc to ensure Vebox input size is same with target Dstrec.
+    if (pSurfaceParam->bVEBOXCroppingUsed)
+    {
+        *pdwSurfaceHeight = MOS_ALIGN_CEIL(
+            MOS_MIN(pSurfaceParam->dwHeight, MOS_MAX((uint32_t)pSurfaceParam->rcSrc.bottom, MHW_VEBOX_MIN_HEIGHT)),
+            wHeightAlignUnit);
+        *pdwSurfaceWidth = MOS_ALIGN_CEIL(
+            MOS_MIN(pSurfaceParam->dwWidth, MOS_MAX((uint32_t)pSurfaceParam->rcSrc.right, MHW_VEBOX_MIN_WIDTH)),
+            wWidthAlignUnit);
+        MHW_NORMALMESSAGE("bVEBOXCroppingUsed = true, pSurfaceParam->rcSrc.bottom: %d, pSurfaceParam->rcSrc.right: %d; pdwSurfaceHeight: %d, pdwSurfaceWidth: %d;",
+            (uint32_t)pSurfaceParam->rcSrc.bottom,
+            (uint32_t)pSurfaceParam->rcSrc.right,
+            *pdwSurfaceHeight,
+            *pdwSurfaceWidth);
+    }
+    else
+    {
+        // Align width and height with max src renctange with consideration of
+        // these conditions:
+        // The minimum of width/height should equal to or larger than
+        // MHW_VEBOX_MIN_WIDTH/HEIGHT. The maximum of width/heigh should equal
+        // to or smaller than surface width/height
+        *pdwSurfaceHeight = MOS_ALIGN_CEIL(
+            MOS_MIN(pSurfaceParam->dwHeight, MOS_MAX((uint32_t)pSurfaceParam->rcMaxSrc.bottom, MHW_VEBOX_MIN_HEIGHT)),
+            wHeightAlignUnit);
+        *pdwSurfaceWidth = MOS_ALIGN_CEIL(
+            MOS_MIN(pSurfaceParam->dwWidth, MOS_MAX((uint32_t)pSurfaceParam->rcMaxSrc.right, MHW_VEBOX_MIN_WIDTH)),
+            wWidthAlignUnit);
+        MHW_NORMALMESSAGE("bVEBOXCroppingUsed = false, pSurfaceParam->rcMaxSrc.bottom: %d, pSurfaceParam->rcMaxSrc.right: %d; pdwSurfaceHeight: %d, pdwSurfaceWidth: %d;",
+            (uint32_t)pSurfaceParam->rcMaxSrc.bottom,
+            (uint32_t)pSurfaceParam->rcMaxSrc.right,
+            *pdwSurfaceHeight,
+            *pdwSurfaceWidth);
+    }
+
 
 finish:
     return eStatus;
