@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017-2018, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -185,10 +185,10 @@ MOS_STATUS GraphicsResourceSpecific::Allocate(OsContext* osContextPtr, CreatePar
     gmmParams.ArraySize = 1;
 
     MOS_TILE_TYPE tileformat = params.m_tileType;
+    MOS_OS_NORMALMESSAGE("tilemode: tileformat = %d for %s, tileModeByForce = %d", tileformat, params.m_name.c_str(), params.m_tileModeByForce);
     switch (tileformat)
     {
         case MOS_TILE_Y:
-            gmmParams.Flags.Gpu.MMC       = params.m_isCompressible;
             tileFormatLinux               = I915_TILING_Y;
             if (params.m_isCompressible && MEDIA_IS_SKU(pOsContextSpecific->GetSkuTable(), FtrE2ECompression))
             {
@@ -203,6 +203,7 @@ MOS_STATUS GraphicsResourceSpecific::Allocate(OsContext* osContextPtr, CreatePar
                     gmmParams.Flags.Gpu.UnifiedAuxSurface = 0;
                 }
             }
+            SetTileModebyForce(gmmParams, params.m_tileModeByForce);
             break;
         case MOS_TILE_X:
             gmmParams.Flags.Info.TiledX   = true;
@@ -356,7 +357,12 @@ MOS_STATUS GraphicsResourceSpecific::Allocate(OsContext* osContextPtr, CreatePar
         m_isCompressed    = gmmResourceInfoPtr->IsMediaMemoryCompressed(0);
         m_compressionMode = (MOS_RESOURCE_MMC_MODE)gmmResourceInfoPtr->GetMmcMode(0);
 
-        MOS_OS_VERBOSEMESSAGE("Alloc %7d bytes (%d x %d resource).",bufSize, params.m_width, bufHeight);
+        m_memObjCtrlState = MosInterface::GetCachePolicyMemoryObject(
+            pOsContextSpecific->GetGmmClientContext(),
+            params.m_mocsMosResUsageType);
+        m_mocsMosResUsageType = params.m_mocsMosResUsageType;
+
+        MOS_OS_VERBOSEMESSAGE("Alloc %7d bytes (%d x %d resource), tile encoding %d.",bufSize, params.m_width, bufHeight, m_tileModeGMM);
 
         struct {
             uint32_t m_handle;
@@ -467,7 +473,10 @@ MOS_STATUS GraphicsResourceSpecific::ConvertToMosResource(MOS_RESOURCE* pMosReso
     pMosResource->MmapOperation = m_mmapOperation;
     pMosResource->pGmmResInfo   = m_gmmResInfo;
 
-    pMosResource->user_provided_va    = m_userProvidedVA;
+    pMosResource->user_provided_va  = m_userProvidedVA;
+
+    pMosResource->memObjCtrlState   = m_memObjCtrlState;
+    pMosResource->mocsMosResUsageType = m_mocsMosResUsageType;
 
     pMosResource->pGfxResource    = this;
 
@@ -646,3 +655,15 @@ MOS_STATUS GraphicsResourceSpecific::Unlock(OsContext* osContextPtr)
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS GraphicsResourceSpecific::SetTileModebyForce(GMM_RESCREATE_PARAMS &gmmParams, MOS_TILE_MODE_GMM tileMode)
+{
+    if (tileMode == MOS_TILE_64_GMM)
+    {
+        gmmParams.Flags.Info.Tile64 = true;
+    }
+    else if (tileMode == MOS_TILE_4_GMM)
+    {
+        gmmParams.Flags.Info.Tile4 = true;
+    }
+    return MOS_STATUS_SUCCESS;
+}
\ No newline at end of file
