@@ -53,7 +53,7 @@ DecodePipeline::DecodePipeline(
     m_hwInterface = hwInterface;
 
     m_singleTaskPhaseSupported =
-        ReadUserFeature(__MEDIA_USER_FEATURE_VALUE_SINGLE_TASK_PHASE_ENABLE_ID, m_osInterface ? m_osInterface->pOsContext : nullptr).i32Data ? true : false;
+        ReadUserFeature(__MEDIA_USER_FEATURE_VALUE_DECODE_SINGLE_TASK_PHASE_ENABLE_ID, m_osInterface ? m_osInterface->pOsContext : nullptr).i32Data ? true : false;
 
     CODECHAL_DEBUG_TOOL(
         DECODE_ASSERT(debugInterface != nullptr);
@@ -459,22 +459,6 @@ MOS_STATUS DecodePipeline::TraceDataDumpOutput(const DecodeStatusReportData &rep
     dstSurface.OsResource = reportData.currDecodedPicRes;
     DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&dstSurface));
 
-    DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
-    {
-        (uint32_t)reportData.currDecodedPic.PicFlags,
-        dstSurface.dwOffset,
-        dstSurface.YPlaneOffset.iYOffset,
-        dstSurface.dwPitch,
-        dstSurface.dwWidth,
-        dstSurface.dwHeight,
-        (uint32_t)dstSurface.Format,
-        dstSurface.UPlaneOffset.iLockSurfaceOffset,
-        dstSurface.VPlaneOffset.iLockSurfaceOffset,
-        dstSurface.UPlaneOffset.iSurfaceOffset,
-        dstSurface.VPlaneOffset.iSurfaceOffset,
-    };
-    MOS_TraceEvent(EVENT_DECODE_SURFACE_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0); 
-
     if (!m_allocator->ResourceIsNull(&dstSurface.OsResource))
     {
         if (m_tempOutputSurf == nullptr || m_allocator->ResourceIsNull(&m_tempOutputSurf->OsResource))
@@ -515,6 +499,23 @@ MOS_STATUS DecodePipeline::TraceDataDumpOutput(const DecodeStatusReportData &rep
             &m_tempOutputSurf->OsResource,
             false));
 
+        DECODE_EVENTDATA_YUV_SURFACE_INFO eventData =
+        {
+            (uint32_t)reportData.currDecodedPic.PicFlags,
+            reportData.frameType,
+            m_tempOutputSurf->dwOffset,
+            m_tempOutputSurf->YPlaneOffset.iYOffset,
+            m_tempOutputSurf->dwPitch,
+            m_tempOutputSurf->dwWidth,
+            m_tempOutputSurf->dwHeight,
+            (uint32_t)m_tempOutputSurf->Format,
+            m_tempOutputSurf->UPlaneOffset.iLockSurfaceOffset,
+            m_tempOutputSurf->VPlaneOffset.iLockSurfaceOffset,
+            m_tempOutputSurf->UPlaneOffset.iSurfaceOffset,
+            m_tempOutputSurf->VPlaneOffset.iSurfaceOffset,
+        };
+        MOS_TraceEvent(EVENT_DECODE_DST_DUMPINFO, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0); 
+
         ResourceAutoLock resLock(m_allocator, &m_tempOutputSurf->OsResource);
         auto             pData = (uint8_t *)resLock.LockResourceForRead();
 
@@ -615,7 +616,7 @@ MOS_STATUS DecodePipeline::StatusCheck()
     uint32_t completedCount = m_statusReport->GetCompletedCount();
     if (completedCount <= m_statusCheckCount)
     {
-        DECODE_CHK_COND(completedCount < m_statusCheckCount, "Invalid status check count");
+        DECODE_NORMALMESSAGE("Invalid status check count, completedCount = %d m_statusCheckCount =%d.", completedCount, m_statusCheckCount);
         return MOS_STATUS_SUCCESS;
     }
 
@@ -661,7 +662,8 @@ MOS_STATUS DecodePipeline::StatusCheck()
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
         if (MOS_GetTraceEventKeyword() & EVENT_DECODE_DSTYUV_KEYWORD)
         {
-            DECODE_CHK_STATUS(TraceDataDumpOutput(reportData));
+            const DecodeStatusReportData &reportETWData = statusReport->GetReportData(m_statusCheckCount);
+            DECODE_CHK_STATUS(TraceDataDumpOutput(reportETWData));
         }
 #endif
 
