@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -89,6 +89,7 @@ enum FeatureType
     FeatureTypeCgcOnVebox       = FeatureTypeCgc | FEATURE_TYPE_ENGINE_BITS_VEBOX,
     FeatureTypeHdr              = 0xC00,
     FeatureTypeHdrOnVebox       = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeHdr3DLutCalOnRender = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_RENDER | FEATURE_TYPE_ENGINE_BITS_SUB_STEP,
     FeatureTypeFD               = 0xD00,
     FeatureTypeFLD              = 0xE00,
     FeatureTypeFB               = 0xF00,
@@ -113,7 +114,11 @@ enum FeatureType
     FeatureTypeColorFillOnRender = FeatureTypeColorFill | FEATURE_TYPE_ENGINE_BITS_RENDER,
     FeatureTypeAlpha            = 0x1900,
     FeatureTypeAlphaOnSfc       = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_SFC,
+    FeatureTypeAlphaOnVebox     = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_VEBOX,
     FeatureTypeAlphaOnRender    = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeCappipe          = 0x2000,
+    FeatureTypeCappipeOnVebox   = FeatureTypeCappipe | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeCappipeOnRender  = FeatureTypeCappipe | FEATURE_TYPE_ENGINE_BITS_RENDER,
     // ...
     NumOfFeatureType
 };
@@ -142,7 +147,8 @@ enum SurfaceType
     SurfaceTypeLaceLut,
     SurfaceTypeStatistics,
     SurfaceTypeSkinScore,
-    SurfaceType3dLut,
+    SurfaceType3DLut,
+    SurfaceType1k1dLut,
     SurfaceType1dLutHDR,
     SurfaceTypeAlphaOrVignette,
     SurfaceTypeVeboxStateHeap_Drv,
@@ -161,6 +167,39 @@ enum SurfaceType
     SurfaceTypePwlfOut,
     SurfaceTypeWeitCoef,
     SurfaceTypGlobalToneMappingCurveLUT,
+    // FC
+    SurfaceTypeFcInputLayer0,
+    SurfaceTypeFcInputLayer1,
+    SurfaceTypeFcInputLayer2,
+    SurfaceTypeFcInputLayer3,
+    SurfaceTypeFcInputLayer4,
+    SurfaceTypeFcInputLayer5,
+    SurfaceTypeFcInputLayer6,
+    SurfaceTypeFcInputLayer7,
+    SurfaceTypeFcInputLayerMax = SurfaceTypeFcInputLayer7,
+    SurfaceTypeFcInputLayer0Field1Dual,
+    SurfaceTypeFcInputLayer1Field1Dual,
+    SurfaceTypeFcInputLayer2Field1Dual,
+    SurfaceTypeFcInputLayer3Field1Dual,
+    SurfaceTypeFcInputLayer4Field1Dual,
+    SurfaceTypeFcInputLayer5Field1Dual,
+    SurfaceTypeFcInputLayer6Field1Dual,
+    SurfaceTypeFcInputLayer7Field1Dual,
+    SurfaceTypeFcInputLayerMaxField1Dual = SurfaceTypeFcInputLayer7Field1Dual,
+    SurfaceTypeFcTarget0,
+    SurfaceTypeFcTarget1,
+    SurfaceTypeFcCscCoeff,
+    // LGCA related Surfaces
+    SurfaceTypeSamplerSurfaceR,
+    SurfaceTypeSamplerSurfaceG,
+    SurfaceTypeSamplerSurfaceB,
+    SurfaceTypeOutputSurfaceR,
+    SurfaceTypeOutputSurfaceG,
+    SurfaceTypeOutputSurfaceB,
+    SurfaceTypeSamplerParamsMinMax,
+    // 3DLut Kernel
+    SurfaceType3DLut2D,
+    SurfaceType3DLutCoef,
     NumberOfSurfaceType
 };
 
@@ -169,16 +208,16 @@ using  VP_SURFACE_GROUP = std::map<SurfaceType, VP_SURFACE*>;
 struct VP_SURFACE_SETTING
 {
     VP_SURFACE_GROUP    surfGroup;
-    bool                isPastHistogramValid;
-    uint32_t            imageWidthOfPastHistogram;
-    uint32_t            imageHeightOfPastHistogram;
-    uint32_t            dwVeboxPerBlockStatisticsHeight;
-    uint32_t            dwVeboxPerBlockStatisticsWidth;
-    uint32_t            aggregateBlockSize;
-    bool                laceLutValid;
-    bool                updateGlobalToneMappingCurveLUTSurface;
-    bool                updateWeitCoefSurface;
-    bool                dumpLaceSurface;
+    bool                isPastHistogramValid       = false;
+    uint32_t            imageWidthOfPastHistogram  = 0;
+    uint32_t            imageHeightOfPastHistogram = 0;
+    uint32_t            dwVeboxPerBlockStatisticsHeight = 0;
+    uint32_t            dwVeboxPerBlockStatisticsWidth  = 0;
+    uint32_t            aggregateBlockSize              = 0;
+    bool                laceLutValid                    = false;
+    bool                updateGlobalToneMappingCurveLUTSurface = false;
+    bool                updateWeitCoefSurface                  = false;
+    bool                dumpLaceSurface                        = false;
 
     void Clean()
     {
@@ -224,9 +263,16 @@ inline bool operator<(FeatureType a, FeatureType b)
 
 struct FeatureParam
 {
-    FeatureType type;
-    MOS_FORMAT  formatInput;
-    MOS_FORMAT  formatOutput;
+    FeatureType type         = FeatureTypeInvalid;
+    MOS_FORMAT  formatInput  = Format_None;
+    MOS_FORMAT  formatOutput = Format_None;
+};
+
+enum FeatureCategory
+{
+    FeatureCategoryBasic    = 0,
+    FeatureCategoryIsolated,
+    FeatureCategoryFC,
 };
 
 class SwFilterSet;
@@ -240,6 +286,7 @@ public:
     {
         MOS_ZeroMemory(&m_EngineCaps, sizeof(m_EngineCaps));
         m_noNeedUpdate = false;
+        m_isInExePipe = false;
         return MOS_STATUS_SUCCESS;
     }
     virtual FeatureType GetFeatureType()
@@ -274,6 +321,7 @@ public:
     {
         return MOS_STATUS_UNIMPLEMENTED;
     }
+
     virtual SwFilter *Clone() = 0;
     virtual bool operator == (class SwFilter&) = 0;
     virtual MOS_STATUS Update(VP_SURFACE *inputSurf, VP_SURFACE *outputSurf, SwFilterSubPipe &pipe) = 0;
@@ -317,6 +365,11 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    void SetExePipeFlag(bool isInExePipe)
+    {
+        m_isInExePipe = isInExePipe;
+    }
+
 protected:
     VpInterface &m_vpInterface;
     FeatureType m_type = FeatureTypeInvalid;
@@ -325,20 +378,23 @@ protected:
     VP_EngineEntry  m_EngineCaps = {};
     bool m_noNeedUpdate = false;
     RenderTargetType m_renderTargetType = RenderTargetTypeSurface;
+    bool m_isInExePipe = false;
+
+MEDIA_CLASS_DEFINE_END(SwFilter)
 };
 
 struct FeatureParamCsc : public FeatureParam
 {
     struct CSC_PARAMS
     {
-        VPHAL_CSPACE    colorSpace;
-        uint32_t        chromaSiting;
+        VPHAL_CSPACE    colorSpace      = CSpace_None;
+        uint32_t        chromaSiting    = 0;
     };
-    CSC_PARAMS          input;
-    CSC_PARAMS          output;
-    PVPHAL_IEF_PARAMS   pIEFParams;
-    PVPHAL_ALPHA_PARAMS pAlphaParams;
-    FeatureParamCsc     *next;                //!< pointe to new/next generated CSC params
+    CSC_PARAMS          input           = {};
+    CSC_PARAMS          output          = {};
+    PVPHAL_IEF_PARAMS   pIEFParams      = nullptr;
+    PVPHAL_ALPHA_PARAMS pAlphaParams    = nullptr;
+    FeatureParamCsc     *next           = nullptr;                //!< pointe to new/next generated CSC params
 };
 
 class SwFilterCsc : public SwFilter
@@ -359,41 +415,43 @@ public:
 
 private:
     FeatureParamCsc m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterCsc)
 };
 
 struct FeatureParamScaling : public FeatureParam
 {
     struct SCALING_PARAMS
     {
-        uint32_t                dwWidth;
-        uint32_t                dwHeight;
-        RECT                    rcSrc;
-        RECT                    rcDst;                          //!< Input dst rect without rotate being applied.
-        RECT                    rcMaxSrc;
-        VPHAL_SAMPLE_TYPE       sampleType;
+        uint32_t                dwWidth  = 0;
+        uint32_t                dwHeight = 0;
+        RECT                    rcSrc    = {0, 0, 0, 0};
+        RECT                    rcDst    = {0, 0, 0, 0};  //!< Input dst rect without rotate being applied.
+        RECT                    rcMaxSrc = {0, 0, 0, 0};
+        VPHAL_SAMPLE_TYPE       sampleType = SAMPLE_PROGRESSIVE;
     };
 
     // Parameters maintained by scaling feature parameters
-    SCALING_PARAMS              input;
-    SCALING_PARAMS              output;
-    bool                        isPrimary;
-    VPHAL_SCALING_MODE          scalingMode;
-    VPHAL_SCALING_PREFERENCE    scalingPreference;              //!< DDI indicate Scaling preference
+    SCALING_PARAMS              input       = {};
+    SCALING_PARAMS              output      = {};
+    bool                        isPrimary   = false;
+    VPHAL_SCALING_MODE          scalingMode = VPHAL_SCALING_NEAREST;
+    VPHAL_SCALING_PREFERENCE    scalingPreference  = VPHAL_SCALING_PREFER_SFC;  //!< DDI indicate Scaling preference
     bool                        bDirectionalScalar = false;     //!< Vebox Directional Scalar
-    PVPHAL_COLORFILL_PARAMS     pColorFillParams;               //!< ColorFill - BG only
-    PVPHAL_ALPHA_PARAMS         pCompAlpha;                     //!< Alpha for composited surfaces
-    VPHAL_ISCALING_TYPE         interlacedScalingType;
+    PVPHAL_COLORFILL_PARAMS     pColorFillParams = nullptr;     //!< ColorFill - BG only
+    PVPHAL_ALPHA_PARAMS         pCompAlpha       = nullptr;     //!< Alpha for composited surfaces
+    VPHAL_ISCALING_TYPE         interlacedScalingType = ISCALING_NONE;
 
     // Parameters maintained by other feature parameters.
     struct {
-        VPHAL_CSPACE            colorSpaceOutput;
+        VPHAL_CSPACE colorSpaceOutput = CSpace_None;
     } csc;
 
     struct {
-        bool                    rotationNeeded;                 //!< Whether rotate SwFilter exists on SwFilterPipe.
+        bool                    rotationNeeded = false;                 //!< Whether rotate SwFilter exists on SwFilterPipe.
     } rotation;
 
-    FeatureParamScaling        *next;                           //!< pointe to new/next generated scaling params
+    FeatureParamScaling        *next = nullptr;                           //!< pointe to new/next generated scaling params
 };
 
 class SwFilterScaling : public SwFilter
@@ -404,23 +462,32 @@ public:
     virtual MOS_STATUS Clean();
     virtual MOS_STATUS Configure(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex);
     virtual MOS_STATUS Configure(VEBOX_SFC_PARAMS &params);
+    virtual MOS_STATUS Configure(PVP_SURFACE surfInput, PVP_SURFACE surfOutput, VP_EXECUTE_CAPS caps);
     virtual FeatureParamScaling &GetSwFilterParams();
     virtual SwFilter *Clone();
     virtual bool operator == (SwFilter& swFilter);
     virtual MOS_STATUS Update(VP_SURFACE *inputSurf, VP_SURFACE *outputSurf, SwFilterSubPipe &pipe);
+    virtual MOS_STATUS SetResourceAssignmentHint(RESOURCE_ASSIGNMENT_HINT &hint)
+    {
+        hint.isIScalingTypeNone = ISCALING_NONE == m_Params.interlacedScalingType;
+        hint.isFieldWeaving     = ISCALING_FIELD_TO_INTERLEAVED == m_Params.interlacedScalingType;
+        return MOS_STATUS_SUCCESS;
+    }
 
 private:
     FeatureParamScaling m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterScaling)
 };
 
 struct FeatureParamRotMir : public FeatureParam
 {
     // Parameters maintained by rotation feature parameters
-    VPHAL_ROTATION rotation;
+    VPHAL_ROTATION rotation = VPHAL_ROTATION_IDENTITY;
 
     // Parameters maintained by other feature parameters.
     struct {
-        MOS_TILE_TYPE  tileOutput;
+        MOS_TILE_TYPE tileOutput = MOS_TILE_X;
     } surfInfo;
 };
 
@@ -439,15 +506,18 @@ public:
 
 private:
     FeatureParamRotMir m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterRotMir)
 };
 
 struct FeatureParamDenoise : public FeatureParam
 {
-    VPHAL_SAMPLE_TYPE    sampleTypeInput;
-    VPHAL_DENOISE_PARAMS denoiseParams;
-    uint32_t             widthAlignUnitInput;
-    uint32_t             heightAlignUnitInput;
-    uint32_t             heightInput;
+    VPHAL_SAMPLE_TYPE    sampleTypeInput      = SAMPLE_PROGRESSIVE;
+    VPHAL_DENOISE_PARAMS denoiseParams        = {};
+    uint32_t             widthAlignUnitInput  = 0;
+    uint32_t             heightAlignUnitInput = 0;
+    uint32_t             heightInput          = 0;
+    bool                 secureDnNeeded       = false;
 };
 
 class SwFilterDenoise : public SwFilter
@@ -464,16 +534,20 @@ public:
 
 private:
     FeatureParamDenoise m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterDenoise)
 };
 
 struct FeatureParamDeinterlace : public FeatureParam
 {
-    VPHAL_SAMPLE_TYPE       sampleTypeInput;
-    bool                    bHDContent;
-    PVPHAL_DI_PARAMS        diParams;
-    bool                    bFmdExtraVariance;    //!< Check if extra FMD variances need to be calculated
-    bool                    bFmdKernelEnable;     //!< FMD kernel path enabled
-    bool                    bQueryVarianceEnable; //!< Query variance enabled
+    VPHAL_SAMPLE_TYPE       sampleTypeInput      = SAMPLE_PROGRESSIVE;
+    bool                    bHDContent           = false;
+    PVPHAL_DI_PARAMS        diParams             = nullptr;
+    bool                    bFmdExtraVariance    = false;     //!< Check if extra FMD variances need to be calculated
+    bool                    bFmdKernelEnable     = false;     //!< FMD kernel path enabled
+    bool                    bQueryVarianceEnable = false;     //!< Query variance enabled
+    uint32_t                heightInput          = 0;
+    RECT                    rcSrc                = {0, 0, 0, 0};
 };
 
 class SwFilterDeinterlace : public SwFilter
@@ -496,12 +570,14 @@ public:
 
 private:
     FeatureParamDeinterlace m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterDeinterlace)
 };
 
 struct FeatureParamSte : public FeatureParam
 {
-    bool                bEnableSTE;
-    uint32_t            dwSTEFactor;
+    bool       bEnableSTE  = false;
+    uint32_t   dwSTEFactor = 0;
 };
 
 class SwFilterSte : public SwFilter
@@ -518,17 +594,19 @@ public:
 
 private:
     FeatureParamSte m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterSte)
 };
 
 struct FeatureParamTcc : public FeatureParam
 {
-    bool                bEnableTCC;
-    uint8_t             Red;
-    uint8_t             Green;
-    uint8_t             Blue;
-    uint8_t             Cyan;
-    uint8_t             Magenta;
-    uint8_t             Yellow;
+    bool                bEnableTCC = false;
+    uint8_t             Red        = 0;
+    uint8_t             Green      = 0;
+    uint8_t             Blue       = 0;
+    uint8_t             Cyan       = 0;
+    uint8_t             Magenta    = 0;
+    uint8_t             Yellow     = 0;
 };
 
 class SwFilterTcc : public SwFilter
@@ -545,11 +623,13 @@ public:
 
 private:
     FeatureParamTcc m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterTcc)
 };
 
 struct FeatureParamProcamp : public FeatureParam
 {
-    PVPHAL_PROCAMP_PARAMS procampParams;
+    PVPHAL_PROCAMP_PARAMS procampParams = nullptr;
 };
 
 class SwFilterProcamp : public SwFilter
@@ -566,15 +646,26 @@ public:
 
 private:
     FeatureParamProcamp m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterProcamp)
+};
+
+enum HDR_STAGE
+{
+    HDR_STAGE_DEFAULT = 0,
+    HDR_STAGE_3DLUT_KERNEL,
+    HDR_STAGE_VEBOX_3DLUT_UPDATE,
+    HDR_STAGE_VEBOX_3DLUT_NO_UPDATE,
 };
 
 struct FeatureParamHdr : public FeatureParam
 {
-    uint32_t        uiMaxDisplayLum;       //!< Maximum Display Luminance
-    uint32_t        uiMaxContentLevelLum;  //!< Maximum Content Level Luminance
-    VPHAL_HDR_MODE  hdrMode;
-    VPHAL_CSPACE    srcColorSpace;
-    VPHAL_CSPACE    dstColorSpace;
+    uint32_t        uiMaxDisplayLum      = 0;  //!< Maximum Display Luminance
+    uint32_t        uiMaxContentLevelLum = 0;  //!< Maximum Content Level Luminance
+    VPHAL_HDR_MODE  hdrMode              = VPHAL_HDR_MODE_NONE;
+    VPHAL_CSPACE    srcColorSpace        = CSpace_None;
+    VPHAL_CSPACE    dstColorSpace        = CSpace_None;
+    HDR_STAGE       stage                = HDR_STAGE_DEFAULT;
 };
 
 class SwFilterHdr : public SwFilter
@@ -588,14 +679,68 @@ public:
     virtual SwFilter *       Clone();
     virtual bool             operator==(SwFilter &swFilter);
     virtual MOS_STATUS       Update(VP_SURFACE *inputSurf, VP_SURFACE *outputSurf, SwFilterSubPipe &pipe);
+    virtual MOS_STATUS SetResourceAssignmentHint(RESOURCE_ASSIGNMENT_HINT &hint)
+    {
+        hint.is3DLut2DNeeded = HDR_STAGE_3DLUT_KERNEL == m_Params.stage ||
+                               HDR_STAGE_VEBOX_3DLUT_UPDATE == m_Params.stage;
+        return MOS_STATUS_SUCCESS;
+    }
 
 private:
     FeatureParamHdr m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterHdr)
+};
+
+struct FeatureParamLumakey : public FeatureParam
+{
+    PVPHAL_LUMAKEY_PARAMS lumaKeyParams = nullptr;
+};
+
+class SwFilterLumakey : public SwFilter
+{
+public:
+    SwFilterLumakey(VpInterface &vpInterface);
+    virtual ~SwFilterLumakey();
+    virtual MOS_STATUS       Clean();
+    virtual MOS_STATUS       Configure(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex);
+    virtual FeatureParamLumakey &GetSwFilterParams();
+    virtual SwFilter *       Clone();
+    virtual bool             operator==(SwFilter &swFilter);
+    virtual MOS_STATUS       Update(VP_SURFACE *inputSurf, VP_SURFACE *outputSurf, SwFilterSubPipe &pipe);
+
+private:
+    FeatureParamLumakey m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterLumakey)
+};
+
+struct FeatureParamBlending : public FeatureParam
+{
+    PVPHAL_BLENDING_PARAMS  blendingParams = nullptr;
+};
+
+class SwFilterBlending : public SwFilter
+{
+public:
+    SwFilterBlending(VpInterface &vpInterface);
+    virtual ~SwFilterBlending();
+    virtual MOS_STATUS       Clean();
+    virtual MOS_STATUS       Configure(VP_PIPELINE_PARAMS &params, bool isInputSurf, int surfIndex);
+    virtual FeatureParamBlending &GetSwFilterParams();
+    virtual SwFilter *       Clone();
+    virtual bool             operator==(SwFilter &swFilter);
+    virtual MOS_STATUS       Update(VP_SURFACE *inputSurf, VP_SURFACE *outputSurf, SwFilterSubPipe &pipe);
+
+private:
+    FeatureParamBlending m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterBlending)
 };
 
 struct FeatureParamColorFill : public FeatureParam
 {
-    PVPHAL_COLORFILL_PARAMS colorFillParams;     //!< ColorFill - BG only
+    PVPHAL_COLORFILL_PARAMS colorFillParams = nullptr;     //!< ColorFill - BG only
 };
 
 class SwFilterColorFill : public SwFilter
@@ -613,11 +758,14 @@ public:
 
 private:
     FeatureParamColorFill m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterColorFill)
 };
 
 struct FeatureParamAlpha : public FeatureParam
 {
-    PVPHAL_ALPHA_PARAMS     compAlpha;           //!< Alpha for composited surface
+    PVPHAL_ALPHA_PARAMS     compAlpha         = nullptr;      //!< Alpha for composited surface
+    bool                    calculatingAlpha  = false;        //!< Alpha calculation parameters
 };
 
 class SwFilterAlpha : public SwFilter
@@ -634,6 +782,8 @@ public:
 
 private:
     FeatureParamAlpha m_Params = {};
+
+MEDIA_CLASS_DEFINE_END(SwFilterAlpha)
 };
 
 class SwFilterSet
@@ -660,6 +810,8 @@ private:
     std::map<FeatureType, SwFilter *> m_swFilters;
     // nullptr if it is unordered filters, otherwise, it's the pointer to m_OrderedFilters it belongs to.
     std::vector<class SwFilterSet *> *m_location = nullptr;
+
+MEDIA_CLASS_DEFINE_END(SwFilterSet)
 };
 
 }
