@@ -34,6 +34,7 @@
 #include "vp_packet_pipe.h"
 #include "vp_platform_interface.h"
 #include "vp_utils.h"
+#include "vp_user_feature_control.h"
 using namespace vp;
 
 VpPipeline::VpPipeline(PMOS_INTERFACE osInterface) :
@@ -85,6 +86,13 @@ VpPipeline::~VpPipeline()
         MOS_FreeMemory(m_vpSettings);
         m_vpSettings = nullptr;
     }
+
+    if (m_userFeatureControl &&
+        (this == m_userFeatureControl->m_owner || nullptr == m_userFeatureControl->m_owner))
+    {
+        MOS_Delete(m_userFeatureControl);
+        m_vpMhwInterface.m_userFeatureControl = nullptr;
+    }
 }
 
 MOS_STATUS VpPipeline::GetStatusReport(void *status, uint16_t numStatus)
@@ -122,12 +130,12 @@ MOS_STATUS VpPipeline::UserFeatureReport()
 
     if (m_reporting)
     {
-        m_reporting->OutputPipeMode = m_vpOutputPipe;
-        m_reporting->VEFeatureInUse = m_veboxFeatureInuse;
+        m_reporting->GetFeatures().outputPipeMode = m_vpOutputPipe;
+        m_reporting->GetFeatures().veFeatureInUse = m_veboxFeatureInuse;
 
         if (m_mmc)
         {
-            m_reporting->VPMMCInUse = m_mmc->IsMmcEnabled();
+            m_reporting->GetFeatures().vpMMCInUse = m_mmc->IsMmcEnabled();
         }
 
         if (PIPELINE_PARAM_TYPE_LEGACY == m_pvpParams.type)
@@ -136,14 +144,14 @@ MOS_STATUS VpPipeline::UserFeatureReport()
             VP_PUBLIC_CHK_NULL_RETURN(params);
             if (params->pSrc[0] && params->pSrc[0]->bCompressible)
             {
-                m_reporting->PrimaryCompressible = true;
-                m_reporting->PrimaryCompressMode = (uint8_t)(params->pSrc[0]->CompressionMode);
+                m_reporting->GetFeatures().primaryCompressible = true;
+                m_reporting->GetFeatures().primaryCompressMode = (uint8_t)(params->pSrc[0]->CompressionMode);
             }
 
             if (params->pTarget[0]->bCompressible)
             {
-                m_reporting->RTCompressible = true;
-                m_reporting->RTCompressMode = (uint8_t)(params->pTarget[0]->CompressionMode);
+                m_reporting->GetFeatures().rtCompressible = true;
+                m_reporting->GetFeatures().rtCompressMode = (uint8_t)(params->pTarget[0]->CompressionMode);
             }
         }
     }
@@ -172,6 +180,16 @@ MOS_STATUS VpPipeline::CreatePacketSharedContext()
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS VpPipeline::CreateUserFeatureControl()
+{
+    VP_FUNC_CALL();
+
+    VP_PUBLIC_CHK_NULL_RETURN(m_osInterface);
+    m_userFeatureControl = MOS_New(VpUserFeatureControl, *m_osInterface, this);
+    VP_PUBLIC_CHK_NULL_RETURN(m_userFeatureControl);
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS VpPipeline::Init(void *mhwInterface)
 {
     VP_FUNC_CALL();
@@ -226,6 +244,16 @@ MOS_STATUS VpPipeline::Init(void *mhwInterface)
 
     m_vpMhwInterface.m_settings = m_vpSettings;
 
+    if (m_vpMhwInterface.m_userFeatureControl)
+    {
+        m_userFeatureControl = m_vpMhwInterface.m_userFeatureControl;
+    }
+    else
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(CreateUserFeatureControl());
+        m_vpMhwInterface.m_userFeatureControl = m_userFeatureControl;
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -280,6 +308,7 @@ MOS_STATUS VpPipeline::ExecuteVpPipeline()
 
     VP_PUBLIC_CHK_STATUS_RETURN(CreateSwFilterPipe(m_pvpParams, swFilterPipes));
     // Notify resourceManager for start of new frame processing.
+    MT_LOG1(MT_VP_HAL_ONNEWFRAME_PROC_START, MT_NORMAL, MT_VP_HAL_ONNEWFRAME_COUNTER, m_frameCounter);
     VP_PUBLIC_CHK_STATUS_RETURN(m_resourceManager->OnNewFrameProcessStart(*swFilterPipes[0]));
 
     for (auto &pipe : swFilterPipes)
@@ -315,6 +344,7 @@ finish:
     m_statusReport->UpdateStatusTableAfterSubmit(eStatus);
     // Notify resourceManager for end of new frame processing.
     m_resourceManager->OnNewFrameProcessEnd();
+    MT_LOG1(MT_VP_HAL_ONNEWFRAME_PROC_END, MT_NORMAL, MT_VP_HAL_ONNEWFRAME_COUNTER, m_frameCounter);
     m_frameCounter++;
     return eStatus;
 }
@@ -433,7 +463,18 @@ MOS_STATUS VpPipeline::GetSystemVeboxNumber()
     }
     else if (m_forceMultiplePipe == MOS_SCALABILITY_ENABLE_MODE_DEFAULT)
     {
-        if (m_vpMhwInterface.m_veboxInterface && !(m_vpMhwInterface.m_veboxInterface->m_veboxScalabilitywith4K))
+        std::shared_ptr<mhw::vebox::Itf> veboxItf = nullptr;
+        if (m_vpMhwInterface.m_veboxInterface)
+        {
+            veboxItf = std::static_pointer_cast<mhw::vebox::Itf>(m_vpMhwInterface.m_veboxInterface->GetNewVeboxInterface());
+        }
+
+        if (veboxItf && !(veboxItf->IsVeboxScalabilitywith4K()))
+        {
+            m_numVebox = 1;
+            return MOS_STATUS_SUCCESS;
+        }
+        else if (m_vpMhwInterface.m_veboxInterface && !(m_vpMhwInterface.m_veboxInterface->m_veboxScalabilitywith4K))
         {
             m_numVebox = 1;
             return MOS_STATUS_SUCCESS;
@@ -609,7 +650,7 @@ MOS_STATUS VpPipeline::SurfaceReplace(PVP_PIPELINE_PARAMS params)
     if (m_userFeatureSetting.enableSFCNv12P010LinearOutput &&
         MOS_TILE_LINEAR != params->pTarget[0]->TileType &&
         (Format_P010 == params->pTarget[0]->Format || Format_NV12 == params->pTarget[0]->Format) &&
-        MEDIA_IS_SKU(skuTable, FtrSFCLinearOutputSupport))
+        MEDIA_IS_SKU(skuTable, FtrSFC420LinearOutputSupport))
     {
         if (!m_tempTargetSurface)
         {
@@ -716,53 +757,40 @@ MOS_STATUS VpPipeline::PrepareVpPipelineParams(PVP_PIPELINE_PARAMS params)
     PMOS_RESOURCE ppSource[VPHAL_MAX_SOURCES] = {nullptr};
     PMOS_RESOURCE ppTarget[VPHAL_MAX_TARGETS] = {nullptr};
 
-    if (!params->pSrc[0])
-    {
-        VP_PUBLIC_NORMALMESSAGE("Not support no source case in APG now \n");
-
-        if (m_currentFrameAPGEnabled)
-        {
-            params->bAPGWorkloadEnable = true;
-            m_currentFrameAPGEnabled = false;
-        }
-        else
-        {
-            params->bAPGWorkloadEnable = false;
-        }
-
-        return MOS_STATUS_UNIMPLEMENTED;
-    }
-
     VP_PUBLIC_CHK_NULL_RETURN(params->pTarget[0]);
     VP_PUBLIC_CHK_NULL_RETURN(m_allocator);
     VP_PUBLIC_CHK_NULL_RETURN(m_featureManager);
 
-    VPHAL_GET_SURFACE_INFO  info;
+    // Can be removed, as all info can be gotten during AllocateVpSurface.
+    VPHAL_GET_SURFACE_INFO  info = {};
+    for (uint32_t i = 0; i < params->uSrcCount; ++i)
+    {
+        MOS_ZeroMemory(&info, sizeof(VPHAL_GET_SURFACE_INFO));
+        VP_PUBLIC_CHK_STATUS_RETURN(m_allocator->GetSurfaceInfo(
+            params->pSrc[i],
+            info));
+    }
 
     MOS_ZeroMemory(&info, sizeof(VPHAL_GET_SURFACE_INFO));
-
-    VP_PUBLIC_CHK_STATUS_RETURN(m_allocator->GetSurfaceInfo(
-        params->pSrc[0],
-        info));
-
-    MOS_ZeroMemory(&info, sizeof(VPHAL_GET_SURFACE_INFO));
-
     VP_PUBLIC_CHK_STATUS_RETURN(m_allocator->GetSurfaceInfo(
         params->pTarget[0],
         info));
 
-    if (params->pSrc[0]->pBwdRef)
+    if (params->uSrcCount>0)
     {
-        MOS_ZeroMemory(&info, sizeof(VPHAL_GET_SURFACE_INFO));
+        if (params->pSrc[0]->pBwdRef)
+        {
+            MOS_ZeroMemory(&info, sizeof(VPHAL_GET_SURFACE_INFO));
 
-        VP_PUBLIC_CHK_STATUS_RETURN(m_allocator->GetSurfaceInfo(
-            params->pSrc[0]->pBwdRef,
-            info));
-    }
+            VP_PUBLIC_CHK_STATUS_RETURN(m_allocator->GetSurfaceInfo(
+                params->pSrc[0]->pBwdRef,
+                info));
+        }
 
-    if (!RECT1_CONTAINS_RECT2(params->pSrc[0]->rcMaxSrc, params->pSrc[0]->rcSrc))
-    {
-        params->pSrc[0]->rcMaxSrc = params->pSrc[0]->rcSrc;
+        if (!RECT1_CONTAINS_RECT2(params->pSrc[0]->rcMaxSrc, params->pSrc[0]->rcSrc))
+        {
+            params->pSrc[0]->rcMaxSrc = params->pSrc[0]->rcSrc;
+        }
     }
 
     bool bApgFuncSupported = false;
@@ -823,7 +851,12 @@ MOS_STATUS VpPipeline::PrepareVpPipelineScalabilityParams(PVP_PIPELINE_PARAMS pa
 {
     VP_FUNC_CALL();
     VP_PUBLIC_CHK_NULL_RETURN(params);
-    VP_PUBLIC_CHK_NULL_RETURN(params->pSrc[0]);
+    if (params->pSrc[0] == nullptr)
+    {
+        VP_PUBLIC_NORMALMESSAGE("No input will not need scalability! ");
+        return MOS_STATUS_SUCCESS;
+    }
+
     VP_PUBLIC_CHK_NULL_RETURN(params->pTarget[0]);
 
     // Disable vesfc scalability when reg key "Enable Vebox Scalability" was set to zero
@@ -871,6 +904,7 @@ MOS_STATUS VpPipeline::Prepare(void * params)
     VP_FUNC_CALL();
 
     VP_PUBLIC_CHK_NULL_RETURN(params);
+    VP_PUBLIC_CHK_NULL_RETURN(m_userFeatureControl);
 
     m_pvpParams = *(VP_PARAMS *)params;
     // Get Output Pipe for Features. It should be configured in ExecuteVpPipeline.
@@ -879,6 +913,7 @@ MOS_STATUS VpPipeline::Prepare(void * params)
 
     if (PIPELINE_PARAM_TYPE_LEGACY == m_pvpParams.type)
     {
+        m_userFeatureControl->Update((PVP_PIPELINE_PARAMS)m_pvpParams.renderParams);
         // VP Execution Params Prepare
         eStatus = PrepareVpPipelineParams(m_pvpParams.renderParams);
         if (eStatus != MOS_STATUS_SUCCESS)
